/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 1.3.33
 * 
 * This file is not intended to be easily readable and contains a number of 
 * coding conventions designed to improve portability and efficiency. Do not make
 * changes to this file unless you know what you are doing--modify the SWIG 
 * interface file instead. 
 * ----------------------------------------------------------------------------- */

#define SWIGRUBY
/* -----------------------------------------------------------------------------
 *  This section contains generic SWIG labels for method/variable
 *  declarations/attributes, and other compiler dependent labels.
 * ----------------------------------------------------------------------------- */

/* template workaround for compilers that cannot correctly implement the C++ standard */
#ifndef SWIGTEMPLATEDISAMBIGUATOR
# if defined(__SUNPRO_CC) && (__SUNPRO_CC <= 0x560)
#  define SWIGTEMPLATEDISAMBIGUATOR template
# elif defined(__HP_aCC)
/* Needed even with `aCC -AA' when `aCC -V' reports HP ANSI C++ B3910B A.03.55 */
/* If we find a maximum version that requires this, the test would be __HP_aCC <= 35500 for A.03.55 */
#  define SWIGTEMPLATEDISAMBIGUATOR template
# else
#  define SWIGTEMPLATEDISAMBIGUATOR
# endif
#endif

/* inline attribute */
#ifndef SWIGINLINE
# if defined(__cplusplus) || (defined(__GNUC__) && !defined(__STRICT_ANSI__))
#   define SWIGINLINE inline
# else
#   define SWIGINLINE
# endif
#endif

/* attribute recognised by some compilers to avoid 'unused' warnings */
#ifndef SWIGUNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define SWIGUNUSED __attribute__ ((__unused__)) 
#   else
#     define SWIGUNUSED
#   endif
# elif defined(__ICC)
#   define SWIGUNUSED __attribute__ ((__unused__)) 
# else
#   define SWIGUNUSED 
# endif
#endif

#ifndef SWIGUNUSEDPARM
# ifdef __cplusplus
#   define SWIGUNUSEDPARM(p)
# else
#   define SWIGUNUSEDPARM(p) p SWIGUNUSED 
# endif
#endif

/* internal SWIG method */
#ifndef SWIGINTERN
# define SWIGINTERN static SWIGUNUSED
#endif

/* internal inline SWIG method */
#ifndef SWIGINTERNINLINE
# define SWIGINTERNINLINE SWIGINTERN SWIGINLINE
#endif

/* exporting methods */
#if (__GNUC__ >= 4) || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4)
#  ifndef GCC_HASCLASSVISIBILITY
#    define GCC_HASCLASSVISIBILITY
#  endif
#endif

#ifndef SWIGEXPORT
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   if defined(STATIC_LINKED)
#     define SWIGEXPORT
#   else
#     define SWIGEXPORT __declspec(dllexport)
#   endif
# else
#   if defined(__GNUC__) && defined(GCC_HASCLASSVISIBILITY)
#     define SWIGEXPORT __attribute__ ((visibility("default")))
#   else
#     define SWIGEXPORT
#   endif
# endif
#endif

/* calling conventions for Windows */
#ifndef SWIGSTDCALL
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   define SWIGSTDCALL __stdcall
# else
#   define SWIGSTDCALL
# endif 
#endif

/* Deal with Microsoft's attempt at deprecating C standard runtime functions */
#if !defined(SWIG_NO_CRT_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_CRT_SECURE_NO_DEPRECATE)
# define _CRT_SECURE_NO_DEPRECATE
#endif

/* Deal with Microsoft's attempt at deprecating methods in the standard C++ library */
#if !defined(SWIG_NO_SCL_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_SCL_SECURE_NO_DEPRECATE)
# define _SCL_SECURE_NO_DEPRECATE
#endif


/* -----------------------------------------------------------------------------
 *  This section contains generic SWIG labels for method/variable
 *  declarations/attributes, and other compiler dependent labels.
 * ----------------------------------------------------------------------------- */

/* template workaround for compilers that cannot correctly implement the C++ standard */
#ifndef SWIGTEMPLATEDISAMBIGUATOR
# if defined(__SUNPRO_CC) && (__SUNPRO_CC <= 0x560)
#  define SWIGTEMPLATEDISAMBIGUATOR template
# elif defined(__HP_aCC)
/* Needed even with `aCC -AA' when `aCC -V' reports HP ANSI C++ B3910B A.03.55 */
/* If we find a maximum version that requires this, the test would be __HP_aCC <= 35500 for A.03.55 */
#  define SWIGTEMPLATEDISAMBIGUATOR template
# else
#  define SWIGTEMPLATEDISAMBIGUATOR
# endif
#endif

/* inline attribute */
#ifndef SWIGINLINE
# if defined(__cplusplus) || (defined(__GNUC__) && !defined(__STRICT_ANSI__))
#   define SWIGINLINE inline
# else
#   define SWIGINLINE
# endif
#endif

/* attribute recognised by some compilers to avoid 'unused' warnings */
#ifndef SWIGUNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define SWIGUNUSED __attribute__ ((__unused__)) 
#   else
#     define SWIGUNUSED
#   endif
# elif defined(__ICC)
#   define SWIGUNUSED __attribute__ ((__unused__)) 
# else
#   define SWIGUNUSED 
# endif
#endif

#ifndef SWIGUNUSEDPARM
# ifdef __cplusplus
#   define SWIGUNUSEDPARM(p)
# else
#   define SWIGUNUSEDPARM(p) p SWIGUNUSED 
# endif
#endif

/* internal SWIG method */
#ifndef SWIGINTERN
# define SWIGINTERN static SWIGUNUSED
#endif

/* internal inline SWIG method */
#ifndef SWIGINTERNINLINE
# define SWIGINTERNINLINE SWIGINTERN SWIGINLINE
#endif

/* exporting methods */
#if (__GNUC__ >= 4) || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4)
#  ifndef GCC_HASCLASSVISIBILITY
#    define GCC_HASCLASSVISIBILITY
#  endif
#endif

#ifndef SWIGEXPORT
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   if defined(STATIC_LINKED)
#     define SWIGEXPORT
#   else
#     define SWIGEXPORT __declspec(dllexport)
#   endif
# else
#   if defined(__GNUC__) && defined(GCC_HASCLASSVISIBILITY)
#     define SWIGEXPORT __attribute__ ((visibility("default")))
#   else
#     define SWIGEXPORT
#   endif
# endif
#endif

/* calling conventions for Windows */
#ifndef SWIGSTDCALL
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   define SWIGSTDCALL __stdcall
# else
#   define SWIGSTDCALL
# endif 
#endif

/* Deal with Microsoft's attempt at deprecating C standard runtime functions */
#if !defined(SWIG_NO_CRT_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_CRT_SECURE_NO_DEPRECATE)
# define _CRT_SECURE_NO_DEPRECATE
#endif

/* Deal with Microsoft's attempt at deprecating methods in the standard C++ library */
#if !defined(SWIG_NO_SCL_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_SCL_SECURE_NO_DEPRECATE)
# define _SCL_SECURE_NO_DEPRECATE
#endif


/* -----------------------------------------------------------------------------
 * swigrun.swg
 *
 * This file contains generic CAPI SWIG runtime support for pointer
 * type checking.
 * ----------------------------------------------------------------------------- */

/* This should only be incremented when either the layout of swig_type_info changes,
   or for whatever reason, the runtime changes incompatibly */
#define SWIG_RUNTIME_VERSION "3"

/* define SWIG_TYPE_TABLE_NAME as "SWIG_TYPE_TABLE" */
#ifdef SWIG_TYPE_TABLE
# define SWIG_QUOTE_STRING(x) #x
# define SWIG_EXPAND_AND_QUOTE_STRING(x) SWIG_QUOTE_STRING(x)
# define SWIG_TYPE_TABLE_NAME SWIG_EXPAND_AND_QUOTE_STRING(SWIG_TYPE_TABLE)
#else
# define SWIG_TYPE_TABLE_NAME
#endif

/*
  You can use the SWIGRUNTIME and SWIGRUNTIMEINLINE macros for
  creating a static or dynamic library from the swig runtime code.
  In 99.9% of the cases, swig just needs to declare them as 'static'.
  
  But only do this if is strictly necessary, ie, if you have problems
  with your compiler or so.
*/

#ifndef SWIGRUNTIME
# define SWIGRUNTIME SWIGINTERN
#endif

#ifndef SWIGRUNTIMEINLINE
# define SWIGRUNTIMEINLINE SWIGRUNTIME SWIGINLINE
#endif

/*  Generic buffer size */
#ifndef SWIG_BUFFER_SIZE
# define SWIG_BUFFER_SIZE 1024
#endif

/* Flags for pointer conversions */
#define SWIG_POINTER_DISOWN        0x1

/* Flags for new pointer objects */
#define SWIG_POINTER_OWN           0x1


/* 
   Flags/methods for returning states.
   
   The swig conversion methods, as ConvertPtr, return and integer 
   that tells if the conversion was successful or not. And if not,
   an error code can be returned (see swigerrors.swg for the codes).
   
   Use the following macros/flags to set or process the returning
   states.
   
   In old swig versions, you usually write code as:

     if (SWIG_ConvertPtr(obj,vptr,ty.flags) != -1) {
       // success code
     } else {
       //fail code
     }

   Now you can be more explicit as:

    int res = SWIG_ConvertPtr(obj,vptr,ty.flags);
    if (SWIG_IsOK(res)) {
      // success code
    } else {
      // fail code
    }

   that seems to be the same, but now you can also do

    Type *ptr;
    int res = SWIG_ConvertPtr(obj,(void **)(&ptr),ty.flags);
    if (SWIG_IsOK(res)) {
      // success code
      if (SWIG_IsNewObj(res) {
        ...
	delete *ptr;
      } else {
        ...
      }
    } else {
      // fail code
    }
    
   I.e., now SWIG_ConvertPtr can return new objects and you can
   identify the case and take care of the deallocation. Of course that
   requires also to SWIG_ConvertPtr to return new result values, as

      int SWIG_ConvertPtr(obj, ptr,...) {         
        if (<obj is ok>) {			       
          if (<need new object>) {		       
            *ptr = <ptr to new allocated object>; 
            return SWIG_NEWOBJ;		       
          } else {				       
            *ptr = <ptr to old object>;	       
            return SWIG_OLDOBJ;		       
          } 				       
        } else {				       
          return SWIG_BADOBJ;		       
        }					       
      }

   Of course, returning the plain '0(success)/-1(fail)' still works, but you can be
   more explicit by returning SWIG_BADOBJ, SWIG_ERROR or any of the
   swig errors code.

   Finally, if the SWIG_CASTRANK_MODE is enabled, the result code
   allows to return the 'cast rank', for example, if you have this

       int food(double)
       int fooi(int);

   and you call
 
      food(1)   // cast rank '1'  (1 -> 1.0)
      fooi(1)   // cast rank '0'

   just use the SWIG_AddCast()/SWIG_CheckState()


 */
#define SWIG_OK                    (0) 
#define SWIG_ERROR                 (-1)
#define SWIG_IsOK(r)               (r >= 0)
#define SWIG_ArgError(r)           ((r != SWIG_ERROR) ? r : SWIG_TypeError)  

/* The CastRankLimit says how many bits are used for the cast rank */
#define SWIG_CASTRANKLIMIT         (1 << 8)
/* The NewMask denotes the object was created (using new/malloc) */
#define SWIG_NEWOBJMASK            (SWIG_CASTRANKLIMIT  << 1)
/* The TmpMask is for in/out typemaps that use temporal objects */
#define SWIG_TMPOBJMASK            (SWIG_NEWOBJMASK << 1)
/* Simple returning values */
#define SWIG_BADOBJ                (SWIG_ERROR)
#define SWIG_OLDOBJ                (SWIG_OK)
#define SWIG_NEWOBJ                (SWIG_OK | SWIG_NEWOBJMASK)
#define SWIG_TMPOBJ                (SWIG_OK | SWIG_TMPOBJMASK)
/* Check, add and del mask methods */
#define SWIG_AddNewMask(r)         (SWIG_IsOK(r) ? (r | SWIG_NEWOBJMASK) : r)
#define SWIG_DelNewMask(r)         (SWIG_IsOK(r) ? (r & ~SWIG_NEWOBJMASK) : r)
#define SWIG_IsNewObj(r)           (SWIG_IsOK(r) && (r & SWIG_NEWOBJMASK))
#define SWIG_AddTmpMask(r)         (SWIG_IsOK(r) ? (r | SWIG_TMPOBJMASK) : r)
#define SWIG_DelTmpMask(r)         (SWIG_IsOK(r) ? (r & ~SWIG_TMPOBJMASK) : r)
#define SWIG_IsTmpObj(r)           (SWIG_IsOK(r) && (r & SWIG_TMPOBJMASK))


/* Cast-Rank Mode */
#if defined(SWIG_CASTRANK_MODE)
#  ifndef SWIG_TypeRank
#    define SWIG_TypeRank             unsigned long
#  endif
#  ifndef SWIG_MAXCASTRANK            /* Default cast allowed */
#    define SWIG_MAXCASTRANK          (2)
#  endif
#  define SWIG_CASTRANKMASK          ((SWIG_CASTRANKLIMIT) -1)
#  define SWIG_CastRank(r)           (r & SWIG_CASTRANKMASK)
SWIGINTERNINLINE int SWIG_AddCast(int r) { 
  return SWIG_IsOK(r) ? ((SWIG_CastRank(r) < SWIG_MAXCASTRANK) ? (r + 1) : SWIG_ERROR) : r;
}
SWIGINTERNINLINE int SWIG_CheckState(int r) { 
  return SWIG_IsOK(r) ? SWIG_CastRank(r) + 1 : 0; 
}
#else /* no cast-rank mode */
#  define SWIG_AddCast
#  define SWIG_CheckState(r) (SWIG_IsOK(r) ? 1 : 0)
#endif




#include <string.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef void *(*swig_converter_func)(void *);
typedef struct swig_type_info *(*swig_dycast_func)(void **);

/* Structure to store inforomation on one type */
typedef struct swig_type_info {
  const char             *name;			/* mangled name of this type */
  const char             *str;			/* human readable name of this type */
  swig_dycast_func        dcast;		/* dynamic cast function down a hierarchy */
  struct swig_cast_info  *cast;			/* linked list of types that can cast into this type */
  void                   *clientdata;		/* language specific type data */
  int                    owndata;		/* flag if the structure owns the clientdata */
} swig_type_info;

/* Structure to store a type and conversion function used for casting */
typedef struct swig_cast_info {
  swig_type_info         *type;			/* pointer to type that is equivalent to this type */
  swig_converter_func     converter;		/* function to cast the void pointers */
  struct swig_cast_info  *next;			/* pointer to next cast in linked list */
  struct swig_cast_info  *prev;			/* pointer to the previous cast */
} swig_cast_info;

/* Structure used to store module information
 * Each module generates one structure like this, and the runtime collects
 * all of these structures and stores them in a circularly linked list.*/
typedef struct swig_module_info {
  swig_type_info         **types;		/* Array of pointers to swig_type_info structures that are in this module */
  size_t                 size;		        /* Number of types in this module */
  struct swig_module_info *next;		/* Pointer to next element in circularly linked list */
  swig_type_info         **type_initial;	/* Array of initially generated type structures */
  swig_cast_info         **cast_initial;	/* Array of initially generated casting structures */
  void                    *clientdata;		/* Language specific module data */
} swig_module_info;

/* 
  Compare two type names skipping the space characters, therefore
  "char*" == "char *" and "Class<int>" == "Class<int >", etc.

  Return 0 when the two name types are equivalent, as in
  strncmp, but skipping ' '.
*/
SWIGRUNTIME int
SWIG_TypeNameComp(const char *f1, const char *l1,
		  const char *f2, const char *l2) {
  for (;(f1 != l1) && (f2 != l2); ++f1, ++f2) {
    while ((*f1 == ' ') && (f1 != l1)) ++f1;
    while ((*f2 == ' ') && (f2 != l2)) ++f2;
    if (*f1 != *f2) return (*f1 > *f2) ? 1 : -1;
  }
  return (int)((l1 - f1) - (l2 - f2));
}

/*
  Check type equivalence in a name list like <name1>|<name2>|...
  Return 0 if not equal, 1 if equal
*/
SWIGRUNTIME int
SWIG_TypeEquiv(const char *nb, const char *tb) {
  int equiv = 0;
  const char* te = tb + strlen(tb);
  const char* ne = nb;
  while (!equiv && *ne) {
    for (nb = ne; *ne; ++ne) {
      if (*ne == '|') break;
    }
    equiv = (SWIG_TypeNameComp(nb, ne, tb, te) == 0) ? 1 : 0;
    if (*ne) ++ne;
  }
  return equiv;
}

/*
  Check type equivalence in a name list like <name1>|<name2>|...
  Return 0 if equal, -1 if nb < tb, 1 if nb > tb
*/
SWIGRUNTIME int
SWIG_TypeCompare(const char *nb, const char *tb) {
  int equiv = 0;
  const char* te = tb + strlen(tb);
  const char* ne = nb;
  while (!equiv && *ne) {
    for (nb = ne; *ne; ++ne) {
      if (*ne == '|') break;
    }
    equiv = (SWIG_TypeNameComp(nb, ne, tb, te) == 0) ? 1 : 0;
    if (*ne) ++ne;
  }
  return equiv;
}


/* think of this as a c++ template<> or a scheme macro */
#define SWIG_TypeCheck_Template(comparison, ty)         \
  if (ty) {                                             \
    swig_cast_info *iter = ty->cast;                    \
    while (iter) {                                      \
      if (comparison) {                                 \
        if (iter == ty->cast) return iter;              \
        /* Move iter to the top of the linked list */   \
        iter->prev->next = iter->next;                  \
        if (iter->next)                                 \
          iter->next->prev = iter->prev;                \
        iter->next = ty->cast;                          \
        iter->prev = 0;                                 \
        if (ty->cast) ty->cast->prev = iter;            \
        ty->cast = iter;                                \
        return iter;                                    \
      }                                                 \
      iter = iter->next;                                \
    }                                                   \
  }                                                     \
  return 0

/*
  Check the typename
*/
SWIGRUNTIME swig_cast_info *
SWIG_TypeCheck(const char *c, swig_type_info *ty) {
  SWIG_TypeCheck_Template(strcmp(iter->type->name, c) == 0, ty);
}

/* Same as previous function, except strcmp is replaced with a pointer comparison */
SWIGRUNTIME swig_cast_info *
SWIG_TypeCheckStruct(swig_type_info *from, swig_type_info *into) {
  SWIG_TypeCheck_Template(iter->type == from, into);
}

/*
  Cast a pointer up an inheritance hierarchy
*/
SWIGRUNTIMEINLINE void *
SWIG_TypeCast(swig_cast_info *ty, void *ptr) {
  return ((!ty) || (!ty->converter)) ? ptr : (*ty->converter)(ptr);
}

/* 
   Dynamic pointer casting. Down an inheritance hierarchy
*/
SWIGRUNTIME swig_type_info *
SWIG_TypeDynamicCast(swig_type_info *ty, void **ptr) {
  swig_type_info *lastty = ty;
  if (!ty || !ty->dcast) return ty;
  while (ty && (ty->dcast)) {
    ty = (*ty->dcast)(ptr);
    if (ty) lastty = ty;
  }
  return lastty;
}

/*
  Return the name associated with this type
*/
SWIGRUNTIMEINLINE const char *
SWIG_TypeName(const swig_type_info *ty) {
  return ty->name;
}

/*
  Return the pretty name associated with this type,
  that is an unmangled type name in a form presentable to the user.
*/
SWIGRUNTIME const char *
SWIG_TypePrettyName(const swig_type_info *type) {
  /* The "str" field contains the equivalent pretty names of the
     type, separated by vertical-bar characters.  We choose
     to print the last name, as it is often (?) the most
     specific. */
  if (!type) return NULL;
  if (type->str != NULL) {
    const char *last_name = type->str;
    const char *s;
    for (s = type->str; *s; s++)
      if (*s == '|') last_name = s+1;
    return last_name;
  }
  else
    return type->name;
}

/* 
   Set the clientdata field for a type
*/
SWIGRUNTIME void
SWIG_TypeClientData(swig_type_info *ti, void *clientdata) {
  swig_cast_info *cast = ti->cast;
  /* if (ti->clientdata == clientdata) return; */
  ti->clientdata = clientdata;
  
  while (cast) {
    if (!cast->converter) {
      swig_type_info *tc = cast->type;
      if (!tc->clientdata) {
	SWIG_TypeClientData(tc, clientdata);
      }
    }    
    cast = cast->next;
  }
}
SWIGRUNTIME void
SWIG_TypeNewClientData(swig_type_info *ti, void *clientdata) {
  SWIG_TypeClientData(ti, clientdata);
  ti->owndata = 1;
}
  
/*
  Search for a swig_type_info structure only by mangled name
  Search is a O(log #types)
  
  We start searching at module start, and finish searching when start == end.  
  Note: if start == end at the beginning of the function, we go all the way around
  the circular list.
*/
SWIGRUNTIME swig_type_info *
SWIG_MangledTypeQueryModule(swig_module_info *start, 
                            swig_module_info *end, 
		            const char *name) {
  swig_module_info *iter = start;
  do {
    if (iter->size) {
      register size_t l = 0;
      register size_t r = iter->size - 1;
      do {
	/* since l+r >= 0, we can (>> 1) instead (/ 2) */
	register size_t i = (l + r) >> 1; 
	const char *iname = iter->types[i]->name;
	if (iname) {
	  register int compare = strcmp(name, iname);
	  if (compare == 0) {	    
	    return iter->types[i];
	  } else if (compare < 0) {
	    if (i) {
	      r = i - 1;
	    } else {
	      break;
	    }
	  } else if (compare > 0) {
	    l = i + 1;
	  }
	} else {
	  break; /* should never happen */
	}
      } while (l <= r);
    }
    iter = iter->next;
  } while (iter != end);
  return 0;
}

/*
  Search for a swig_type_info structure for either a mangled name or a human readable name.
  It first searches the mangled names of the types, which is a O(log #types)
  If a type is not found it then searches the human readable names, which is O(#types).
  
  We start searching at module start, and finish searching when start == end.  
  Note: if start == end at the beginning of the function, we go all the way around
  the circular list.
*/
SWIGRUNTIME swig_type_info *
SWIG_TypeQueryModule(swig_module_info *start, 
                     swig_module_info *end, 
		     const char *name) {
  /* STEP 1: Search the name field using binary search */
  swig_type_info *ret = SWIG_MangledTypeQueryModule(start, end, name);
  if (ret) {
    return ret;
  } else {
    /* STEP 2: If the type hasn't been found, do a complete search
       of the str field (the human readable name) */
    swig_module_info *iter = start;
    do {
      register size_t i = 0;
      for (; i < iter->size; ++i) {
	if (iter->types[i]->str && (SWIG_TypeEquiv(iter->types[i]->str, name)))
	  return iter->types[i];
      }
      iter = iter->next;
    } while (iter != end);
  }
  
  /* neither found a match */
  return 0;
}

/* 
   Pack binary data into a string
*/
SWIGRUNTIME char *
SWIG_PackData(char *c, void *ptr, size_t sz) {
  static const char hex[17] = "0123456789abcdef";
  register const unsigned char *u = (unsigned char *) ptr;
  register const unsigned char *eu =  u + sz;
  for (; u != eu; ++u) {
    register unsigned char uu = *u;
    *(c++) = hex[(uu & 0xf0) >> 4];
    *(c++) = hex[uu & 0xf];
  }
  return c;
}

/* 
   Unpack binary data from a string
*/
SWIGRUNTIME const char *
SWIG_UnpackData(const char *c, void *ptr, size_t sz) {
  register unsigned char *u = (unsigned char *) ptr;
  register const unsigned char *eu = u + sz;
  for (; u != eu; ++u) {
    register char d = *(c++);
    register unsigned char uu;
    if ((d >= '0') && (d <= '9'))
      uu = ((d - '0') << 4);
    else if ((d >= 'a') && (d <= 'f'))
      uu = ((d - ('a'-10)) << 4);
    else 
      return (char *) 0;
    d = *(c++);
    if ((d >= '0') && (d <= '9'))
      uu |= (d - '0');
    else if ((d >= 'a') && (d <= 'f'))
      uu |= (d - ('a'-10));
    else 
      return (char *) 0;
    *u = uu;
  }
  return c;
}

/* 
   Pack 'void *' into a string buffer.
*/
SWIGRUNTIME char *
SWIG_PackVoidPtr(char *buff, void *ptr, const char *name, size_t bsz) {
  char *r = buff;
  if ((2*sizeof(void *) + 2) > bsz) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r,&ptr,sizeof(void *));
  if (strlen(name) + 1 > (bsz - (r - buff))) return 0;
  strcpy(r,name);
  return buff;
}

SWIGRUNTIME const char *
SWIG_UnpackVoidPtr(const char *c, void **ptr, const char *name) {
  if (*c != '_') {
    if (strcmp(c,"NULL") == 0) {
      *ptr = (void *) 0;
      return name;
    } else {
      return 0;
    }
  }
  return SWIG_UnpackData(++c,ptr,sizeof(void *));
}

SWIGRUNTIME char *
SWIG_PackDataName(char *buff, void *ptr, size_t sz, const char *name, size_t bsz) {
  char *r = buff;
  size_t lname = (name ? strlen(name) : 0);
  if ((2*sz + 2 + lname) > bsz) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r,ptr,sz);
  if (lname) {
    strncpy(r,name,lname+1);
  } else {
    *r = 0;
  }
  return buff;
}

SWIGRUNTIME const char *
SWIG_UnpackDataName(const char *c, void *ptr, size_t sz, const char *name) {
  if (*c != '_') {
    if (strcmp(c,"NULL") == 0) {
      memset(ptr,0,sz);
      return name;
    } else {
      return 0;
    }
  }
  return SWIG_UnpackData(++c,ptr,sz);
}

#ifdef __cplusplus
}
#endif

/*  Errors in SWIG */
#define  SWIG_UnknownError    	   -1 
#define  SWIG_IOError        	   -2 
#define  SWIG_RuntimeError   	   -3 
#define  SWIG_IndexError     	   -4 
#define  SWIG_TypeError      	   -5 
#define  SWIG_DivisionByZero 	   -6 
#define  SWIG_OverflowError  	   -7 
#define  SWIG_SyntaxError    	   -8 
#define  SWIG_ValueError     	   -9 
#define  SWIG_SystemError    	   -10
#define  SWIG_AttributeError 	   -11
#define  SWIG_MemoryError    	   -12 
#define  SWIG_NullReferenceError   -13



#include <ruby.h>

/* Remove global macros defined in Ruby's win32.h */
#ifdef write
# undef write
#endif
#ifdef read
# undef read
#endif


/* Ruby 1.7 defines NUM2LL(), LL2NUM() and ULL2NUM() macros */
#ifndef NUM2LL
#define NUM2LL(x) NUM2LONG((x))
#endif
#ifndef LL2NUM
#define LL2NUM(x) INT2NUM((long) (x))
#endif
#ifndef ULL2NUM
#define ULL2NUM(x) UINT2NUM((unsigned long) (x))
#endif

/* Ruby 1.7 doesn't (yet) define NUM2ULL() */
#ifndef NUM2ULL
#ifdef HAVE_LONG_LONG
#define NUM2ULL(x) rb_num2ull((x))
#else
#define NUM2ULL(x) NUM2ULONG(x)
#endif
#endif

/* RSTRING_LEN, etc are new in Ruby 1.9, but ->ptr and ->len no longer work */
/* Define these for older versions so we can just write code the new way */
#ifndef RSTRING_LEN
# define RSTRING_LEN(x) RSTRING(x)->len
#endif
#ifndef RSTRING_PTR
# define RSTRING_PTR(x) RSTRING(x)->ptr
#endif
#ifndef RARRAY_LEN
# define RARRAY_LEN(x) RARRAY(x)->len
#endif
#ifndef RARRAY_PTR
# define RARRAY_PTR(x) RARRAY(x)->ptr
#endif

/*
 * Need to be very careful about how these macros are defined, especially
 * when compiling C++ code or C code with an ANSI C compiler.
 *
 * VALUEFUNC(f) is a macro used to typecast a C function that implements
 * a Ruby method so that it can be passed as an argument to API functions
 * like rb_define_method() and rb_define_singleton_method().
 *
 * VOIDFUNC(f) is a macro used to typecast a C function that implements
 * either the "mark" or "free" stuff for a Ruby Data object, so that it
 * can be passed as an argument to API functions like Data_Wrap_Struct()
 * and Data_Make_Struct().
 */
 
#ifdef __cplusplus
#  ifndef RUBY_METHOD_FUNC /* These definitions should work for Ruby 1.4.6 */
#    define PROTECTFUNC(f) ((VALUE (*)()) f)
#    define VALUEFUNC(f) ((VALUE (*)()) f)
#    define VOIDFUNC(f)  ((void (*)()) f)
#  else
#    ifndef ANYARGS /* These definitions should work for Ruby 1.6 */
#      define PROTECTFUNC(f) ((VALUE (*)()) f)
#      define VALUEFUNC(f) ((VALUE (*)()) f)
#      define VOIDFUNC(f)  ((RUBY_DATA_FUNC) f)
#    else /* These definitions should work for Ruby 1.7+ */
#      define PROTECTFUNC(f) ((VALUE (*)(VALUE)) f)
#      define VALUEFUNC(f) ((VALUE (*)(ANYARGS)) f)
#      define VOIDFUNC(f)  ((RUBY_DATA_FUNC) f)
#    endif
#  endif
#else
#  define VALUEFUNC(f) (f)
#  define VOIDFUNC(f) (f)
#endif

/* Don't use for expressions have side effect */
#ifndef RB_STRING_VALUE
#define RB_STRING_VALUE(s) (TYPE(s) == T_STRING ? (s) : (*(volatile VALUE *)&(s) = rb_str_to_str(s)))
#endif
#ifndef StringValue
#define StringValue(s) RB_STRING_VALUE(s)
#endif
#ifndef StringValuePtr
#define StringValuePtr(s) RSTRING_PTR(RB_STRING_VALUE(s))
#endif
#ifndef StringValueLen
#define StringValueLen(s) RSTRING_LEN(RB_STRING_VALUE(s))
#endif
#ifndef SafeStringValue
#define SafeStringValue(v) do {\
    StringValue(v);\
    rb_check_safe_str(v);\
} while (0)
#endif

#ifndef HAVE_RB_DEFINE_ALLOC_FUNC
#define rb_define_alloc_func(klass, func) rb_define_singleton_method((klass), "new", VALUEFUNC((func)), -1)
#define rb_undef_alloc_func(klass) rb_undef_method(CLASS_OF((klass)), "new")
#endif

static VALUE _mSWIG = Qnil;

/* -----------------------------------------------------------------------------
 * error manipulation
 * ----------------------------------------------------------------------------- */


/* Define some additional error types */
#define SWIG_ObjectPreviouslyDeletedError  -100


/* Define custom exceptions for errors that do not map to existing Ruby
   exceptions.  Note this only works for C++ since a global cannot be
   initialized by a funtion in C.  For C, fallback to rb_eRuntimeError.*/

SWIGINTERN VALUE 
getNullReferenceError(void) {
  static int init = 0;
  static VALUE rb_eNullReferenceError ;
  if (!init) {
    init = 1;
    rb_eNullReferenceError = rb_define_class("NullReferenceError", rb_eRuntimeError);
  }
  return rb_eNullReferenceError;
} 

SWIGINTERN VALUE 
getObjectPreviouslyDeletedError(void) {
  static int init = 0;
  static VALUE rb_eObjectPreviouslyDeleted ;
  if (!init) {
    init = 1;
    rb_eObjectPreviouslyDeleted = rb_define_class("ObjectPreviouslyDeleted", rb_eRuntimeError);
  }
  return rb_eObjectPreviouslyDeleted;
} 


SWIGINTERN VALUE
SWIG_Ruby_ErrorType(int SWIG_code) {
  VALUE type;
  switch (SWIG_code) {
  case SWIG_MemoryError:
    type = rb_eNoMemError;
    break;
  case SWIG_IOError:
    type = rb_eIOError;
    break;
  case SWIG_RuntimeError:
    type = rb_eRuntimeError;
    break;
  case SWIG_IndexError:
    type = rb_eIndexError;
    break;
  case SWIG_TypeError:
    type = rb_eTypeError;
    break;
  case SWIG_DivisionByZero:
    type = rb_eZeroDivError;
    break;
  case SWIG_OverflowError:
    type = rb_eRangeError;
    break;
  case SWIG_SyntaxError:
    type = rb_eSyntaxError;
    break;
  case SWIG_ValueError:
    type = rb_eArgError;
    break;
  case SWIG_SystemError:
    type = rb_eFatal;
    break;
  case SWIG_AttributeError:
    type = rb_eRuntimeError;
    break;
  case SWIG_NullReferenceError:
    type = getNullReferenceError();
    break;
  case SWIG_ObjectPreviouslyDeletedError:
    type = getObjectPreviouslyDeletedError();
    break;
  case SWIG_UnknownError:
    type = rb_eRuntimeError;
    break;
  default:
    type = rb_eRuntimeError;
  }
  return type;
}


/* This function is called when a user inputs a wrong argument to
   a method.
 */
SWIGINTERN 
const char* Ruby_Format_TypeError( const char* msg,
				   const char* type, 
				   const char* name, 
				   const int argn,
				   VALUE input )
{
  char buf[128];
  VALUE str;
  VALUE asStr;
  if ( msg && *msg )
    {
      str = rb_str_new2(msg);
    }
  else
    {
      str = rb_str_new(NULL, 0);
    }

  str = rb_str_cat2( str, "Expected argument " );
  sprintf( buf, "%d of type ", argn-1 );
  str = rb_str_cat2( str, buf );
  str = rb_str_cat2( str, type );
  str = rb_str_cat2( str, ", but got " );
  str = rb_str_cat2( str, rb_obj_classname(input) );
  str = rb_str_cat2( str, " " );
  asStr = rb_inspect(input);
  if ( RSTRING_LEN(asStr) > 30 )
    {
      str = rb_str_cat( str, StringValuePtr(asStr), 30 );
      str = rb_str_cat2( str, "..." );
    }
  else
    {
      str = rb_str_append( str, asStr );
    }

  if ( name )
    {
      str = rb_str_cat2( str, "\n\tin SWIG method '" );
      str = rb_str_cat2( str, name );
      str = rb_str_cat2( str, "'" );
    }

  return StringValuePtr( str );
}

/* This function is called when an overloaded method fails */
SWIGINTERN 
void Ruby_Format_OverloadedError(
				 const int argc,
				 const int maxargs,
				 const char* method, 
				 const char* prototypes 
				 )
{
  const char* msg = "Wrong # of arguments";
  if ( argc <= maxargs ) msg = "Wrong arguments";
  rb_raise(rb_eArgError,"%s for overloaded method '%s'.\n"  
	   "Possible C/C++ prototypes are:\n%s",
	   msg, method, prototypes);
}

/* -----------------------------------------------------------------------------
 * See the LICENSE file for information on copyright, usage and redistribution
 * of SWIG, and the README file for authors - http://www.swig.org/release.html.
 *
 * rubytracking.swg
 *
 * This file contains support for tracking mappings from 
 * Ruby objects to C++ objects.  This functionality is needed
 * to implement mark functions for Ruby's mark and sweep
 * garbage collector.
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#endif

/* Ruby 1.8 actually assumes the first case. */
#if SIZEOF_VOIDP == SIZEOF_LONG
#  define SWIG2NUM(v) LONG2NUM((unsigned long)v)
#  define NUM2SWIG(x) (unsigned long)NUM2LONG(x)
#elif SIZEOF_VOIDP == SIZEOF_LONG_LONG
#  define SWIG2NUM(v) LL2NUM((unsigned long long)v)
#  define NUM2SWIG(x) (unsigned long long)NUM2LL(x)
#else
#  error sizeof(void*) is not the same as long or long long
#endif


/* Global Ruby hash table to store Trackings from C/C++
   structs to Ruby Objects. 
*/
static VALUE swig_ruby_trackings = Qnil;

/* Global variable that stores a reference to the ruby
   hash table delete function. */
static ID swig_ruby_hash_delete;

/* Setup a Ruby hash table to store Trackings */
SWIGRUNTIME void SWIG_RubyInitializeTrackings(void) {
  /* Create a ruby hash table to store Trackings from C++ 
     objects to Ruby objects. */

  /* Try to see if some other .so has already created a 
     tracking hash table, which we keep hidden in an instance var
     in the SWIG module.
     This is done to allow multiple DSOs to share the same
     tracking table.
  */
  ID trackings_id = rb_intern( "@__trackings__" );
  VALUE verbose = rb_gv_get("VERBOSE");
  rb_gv_set("VERBOSE", Qfalse);
  swig_ruby_trackings = rb_ivar_get( _mSWIG, trackings_id );
  rb_gv_set("VERBOSE", verbose);

  /* No, it hasn't.  Create one ourselves */ 
  if ( swig_ruby_trackings == Qnil )
    {
      swig_ruby_trackings = rb_hash_new();
      rb_ivar_set( _mSWIG, trackings_id, swig_ruby_trackings );
    }

  /* Now store a reference to the hash table delete function
     so that we only have to look it up once.*/
  swig_ruby_hash_delete = rb_intern("delete");
}

/* Get a Ruby number to reference a pointer */
SWIGRUNTIME VALUE SWIG_RubyPtrToReference(void* ptr) {
  /* We cast the pointer to an unsigned long
     and then store a reference to it using
     a Ruby number object. */

  /* Convert the pointer to a Ruby number */
  return SWIG2NUM(ptr);
}

/* Get a Ruby number to reference an object */
SWIGRUNTIME VALUE SWIG_RubyObjectToReference(VALUE object) {
  /* We cast the object to an unsigned long
     and then store a reference to it using
     a Ruby number object. */

  /* Convert the Object to a Ruby number */
  return SWIG2NUM(object);
}

/* Get a Ruby object from a previously stored reference */
SWIGRUNTIME VALUE SWIG_RubyReferenceToObject(VALUE reference) {
  /* The provided Ruby number object is a reference
     to the Ruby object we want.*/

  /* Convert the Ruby number to a Ruby object */
  return NUM2SWIG(reference);
}

/* Add a Tracking from a C/C++ struct to a Ruby object */
SWIGRUNTIME void SWIG_RubyAddTracking(void* ptr, VALUE object) {
  /* In a Ruby hash table we store the pointer and
     the associated Ruby object.  The trick here is
     that we cannot store the Ruby object directly - if
     we do then it cannot be garbage collected.  So
     instead we typecast it as a unsigned long and
     convert it to a Ruby number object.*/

  /* Get a reference to the pointer as a Ruby number */
  VALUE key = SWIG_RubyPtrToReference(ptr);

  /* Get a reference to the Ruby object as a Ruby number */
  VALUE value = SWIG_RubyObjectToReference(object);

  /* Store the mapping to the global hash table. */
  rb_hash_aset(swig_ruby_trackings, key, value);
}

/* Get the Ruby object that owns the specified C/C++ struct */
SWIGRUNTIME VALUE SWIG_RubyInstanceFor(void* ptr) {
  /* Get a reference to the pointer as a Ruby number */
  VALUE key = SWIG_RubyPtrToReference(ptr);

  /* Now lookup the value stored in the global hash table */
  VALUE value = rb_hash_aref(swig_ruby_trackings, key);
	
  if (value == Qnil) {
    /* No object exists - return nil. */
    return Qnil;
  }
  else {
    /* Convert this value to Ruby object */
    return SWIG_RubyReferenceToObject(value);
  }
}

/* Remove a Tracking from a C/C++ struct to a Ruby object.  It
   is very important to remove objects once they are destroyed
   since the same memory address may be reused later to create
   a new object. */
SWIGRUNTIME void SWIG_RubyRemoveTracking(void* ptr) {
  /* Get a reference to the pointer as a Ruby number */
  VALUE key = SWIG_RubyPtrToReference(ptr);

  /* Delete the object from the hash table by calling Ruby's
     do this we need to call the Hash.delete method.*/
  rb_funcall(swig_ruby_trackings, swig_ruby_hash_delete, 1, key);
}

/* This is a helper method that unlinks a Ruby object from its
   underlying C++ object.  This is needed if the lifetime of the
   Ruby object is longer than the C++ object */
SWIGRUNTIME void SWIG_RubyUnlinkObjects(void* ptr) {
  VALUE object = SWIG_RubyInstanceFor(ptr);

  if (object != Qnil) {
    DATA_PTR(object) = 0;
  }
}


#ifdef __cplusplus
}
#endif

/* -----------------------------------------------------------------------------
 * Ruby API portion that goes into the runtime
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#endif

SWIGINTERN VALUE
SWIG_Ruby_AppendOutput(VALUE target, VALUE o) {
  if (NIL_P(target)) {
    target = o;
  } else {
    if (TYPE(target) != T_ARRAY) {
      VALUE o2 = target;
      target = rb_ary_new();
      rb_ary_push(target, o2);
    }
    rb_ary_push(target, o);
  }
  return target;
}

/* For ruby1.8.4 and earlier. */
#ifndef RUBY_INIT_STACK
   RUBY_EXTERN void Init_stack(VALUE* addr);
#  define RUBY_INIT_STACK \
   VALUE variable_in_this_stack_frame; \
   Init_stack(&variable_in_this_stack_frame);
#endif


#ifdef __cplusplus
}
#endif


/* -----------------------------------------------------------------------------
 * See the LICENSE file for information on copyright, usage and redistribution
 * of SWIG, and the README file for authors - http://www.swig.org/release.html.
 *
 * rubyrun.swg
 *
 * This file contains the runtime support for Ruby modules
 * and includes code for managing global variables and pointer
 * type checking.
 * ----------------------------------------------------------------------------- */

/* For backward compatibility only */
#define SWIG_POINTER_EXCEPTION  0

/* for raw pointers */
#define SWIG_ConvertPtr(obj, pptr, type, flags)         SWIG_Ruby_ConvertPtrAndOwn(obj, pptr, type, flags, 0)
#define SWIG_ConvertPtrAndOwn(obj,pptr,type,flags,own)  SWIG_Ruby_ConvertPtrAndOwn(obj, pptr, type, flags, own)
#define SWIG_NewPointerObj(ptr, type, flags)            SWIG_Ruby_NewPointerObj(ptr, type, flags)
#define SWIG_AcquirePtr(ptr, own)                       SWIG_Ruby_AcquirePtr(ptr, own)
#define swig_owntype                                    ruby_owntype

/* for raw packed data */
#define SWIG_ConvertPacked(obj, ptr, sz, ty)            SWIG_Ruby_ConvertPacked(obj, ptr, sz, ty, flags)
#define SWIG_NewPackedObj(ptr, sz, type)                SWIG_Ruby_NewPackedObj(ptr, sz, type)

/* for class or struct pointers */
#define SWIG_ConvertInstance(obj, pptr, type, flags)    SWIG_ConvertPtr(obj, pptr, type, flags)
#define SWIG_NewInstanceObj(ptr, type, flags)           SWIG_NewPointerObj(ptr, type, flags)

/* for C or C++ function pointers */
#define SWIG_ConvertFunctionPtr(obj, pptr, type)        SWIG_ConvertPtr(obj, pptr, type, 0)
#define SWIG_NewFunctionPtrObj(ptr, type)               SWIG_NewPointerObj(ptr, type, 0)

/* for C++ member pointers, ie, member methods */
#define SWIG_ConvertMember(obj, ptr, sz, ty)            SWIG_Ruby_ConvertPacked(obj, ptr, sz, ty)
#define SWIG_NewMemberObj(ptr, sz, type)                SWIG_Ruby_NewPackedObj(ptr, sz, type)


/* Runtime API */

#define SWIG_GetModule(clientdata)                      SWIG_Ruby_GetModule()	
#define SWIG_SetModule(clientdata, pointer) 		SWIG_Ruby_SetModule(pointer)


/* Error manipulation */

#define SWIG_ErrorType(code)                            SWIG_Ruby_ErrorType(code)               
#define SWIG_Error(code, msg)            		rb_raise(SWIG_Ruby_ErrorType(code), msg)
#define SWIG_fail                        		goto fail				 


/* Ruby-specific SWIG API */

#define SWIG_InitRuntime()                              SWIG_Ruby_InitRuntime()              
#define SWIG_define_class(ty)                        	SWIG_Ruby_define_class(ty)
#define SWIG_NewClassInstance(value, ty)             	SWIG_Ruby_NewClassInstance(value, ty)
#define SWIG_MangleStr(value)                        	SWIG_Ruby_MangleStr(value)		  
#define SWIG_CheckConvert(value, ty)                 	SWIG_Ruby_CheckConvert(value, ty)	  


/* -----------------------------------------------------------------------------
 * pointers/data manipulation
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#endif

typedef struct {
  VALUE klass;
  VALUE mImpl;
  void  (*mark)(void *);
  void  (*destroy)(void *);
  int trackObjects;
} swig_class;


/* Global pointer used to keep some internal SWIG stuff */
static VALUE _cSWIG_Pointer = Qnil;
static VALUE swig_runtime_data_type_pointer = Qnil;

/* Global IDs used to keep some internal SWIG stuff */
static ID swig_arity_id = 0;
static ID swig_call_id  = 0;

/*
  If your swig extension is to be run within an embedded ruby and has
  director callbacks, you should set -DRUBY_EMBEDDED during compilation.  
  This will reset ruby's stack frame on each entry point from the main 
  program the first time a virtual director function is invoked (in a 
  non-recursive way).
  If this is not done, you run the risk of Ruby trashing the stack.
*/

#ifdef RUBY_EMBEDDED

#  define SWIG_INIT_STACK                            \
      if ( !swig_virtual_calls ) { RUBY_INIT_STACK } \
      ++swig_virtual_calls;
#  define SWIG_RELEASE_STACK --swig_virtual_calls;
#  define Ruby_DirectorTypeMismatchException(x) \
          rb_raise( rb_eTypeError, x ); return c_result;

      static unsigned int swig_virtual_calls = 0;

#else  /* normal non-embedded extension */

#  define SWIG_INIT_STACK
#  define SWIG_RELEASE_STACK
#  define Ruby_DirectorTypeMismatchException(x) \
          throw Swig::DirectorTypeMismatchException( x );

#endif  /* RUBY_EMBEDDED */


SWIGRUNTIME VALUE 
getExceptionClass(void) {
  static int init = 0;
  static VALUE rubyExceptionClass ;
  if (!init) {
    init = 1;
    rubyExceptionClass = rb_const_get(_mSWIG, rb_intern("Exception"));
  }
  return rubyExceptionClass;
} 

/* This code checks to see if the Ruby object being raised as part
   of an exception inherits from the Ruby class Exception.  If so,
   the object is simply returned.  If not, then a new Ruby exception
   object is created and that will be returned to Ruby.*/
SWIGRUNTIME VALUE
SWIG_Ruby_ExceptionType(swig_type_info *desc, VALUE obj) {
  VALUE exceptionClass = getExceptionClass();
  if (rb_obj_is_kind_of(obj, exceptionClass)) {
    return obj;
  }  else {
    return rb_exc_new3(rb_eRuntimeError, rb_obj_as_string(obj));
  }
}

/* Initialize Ruby runtime support */
SWIGRUNTIME void
SWIG_Ruby_InitRuntime(void)
{
  if (_mSWIG == Qnil) {
    _mSWIG = rb_define_module("SWIG");
    swig_call_id  = rb_intern("call");
    swig_arity_id = rb_intern("arity");
  }
}

/* Define Ruby class for C type */
SWIGRUNTIME void
SWIG_Ruby_define_class(swig_type_info *type)
{
  VALUE klass;
  char *klass_name = (char *) malloc(4 + strlen(type->name) + 1);
  sprintf(klass_name, "TYPE%s", type->name);
  if (NIL_P(_cSWIG_Pointer)) {
    _cSWIG_Pointer = rb_define_class_under(_mSWIG, "Pointer", rb_cObject);
    rb_undef_method(CLASS_OF(_cSWIG_Pointer), "new");
  }
  klass = rb_define_class_under(_mSWIG, klass_name, _cSWIG_Pointer);
  free((void *) klass_name);
}

/* Create a new pointer object */
SWIGRUNTIME VALUE
SWIG_Ruby_NewPointerObj(void *ptr, swig_type_info *type, int flags)
{
  int own =  flags & SWIG_POINTER_OWN; 
  int track;
  char *klass_name;
  swig_class *sklass;
  VALUE klass;
  VALUE obj;
  
  if (!ptr)
    return Qnil;
  
  if (type->clientdata) {
    sklass = (swig_class *) type->clientdata;
		
    /* Are we tracking this class and have we already returned this Ruby object? */
    track = sklass->trackObjects;
    if (track) {
      obj = SWIG_RubyInstanceFor(ptr);
      
      /* Check the object's type and make sure it has the correct type.
        It might not in cases where methods do things like 
        downcast methods. */
      if (obj != Qnil) {
        VALUE value = rb_iv_get(obj, "@__swigtype__");
        char* type_name = RSTRING_PTR(value);
				
        if (strcmp(type->name, type_name) == 0) {
          return obj;
        }
      }
    }

    /* Create a new Ruby object */
    obj = Data_Wrap_Struct(sklass->klass, VOIDFUNC(sklass->mark), 
			   ( own ? VOIDFUNC(sklass->destroy) : 
			     (track ? VOIDFUNC(SWIG_RubyRemoveTracking) : 0 )
			     ), ptr);

    /* If tracking is on for this class then track this object. */
    if (track) {
      SWIG_RubyAddTracking(ptr, obj);
    }
  } else {
    klass_name = (char *) malloc(4 + strlen(type->name) + 1);
    sprintf(klass_name, "TYPE%s", type->name);
    klass = rb_const_get(_mSWIG, rb_intern(klass_name));
    free((void *) klass_name);
    obj = Data_Wrap_Struct(klass, 0, 0, ptr);
  }
  rb_iv_set(obj, "@__swigtype__", rb_str_new2(type->name));
  
  return obj;
}

/* Create a new class instance (always owned) */
SWIGRUNTIME VALUE
SWIG_Ruby_NewClassInstance(VALUE klass, swig_type_info *type)
{
  VALUE obj;
  swig_class *sklass = (swig_class *) type->clientdata;
  obj = Data_Wrap_Struct(klass, VOIDFUNC(sklass->mark), VOIDFUNC(sklass->destroy), 0);
  rb_iv_set(obj, "@__swigtype__", rb_str_new2(type->name));
  return obj;
}

/* Get type mangle from class name */
SWIGRUNTIMEINLINE char *
SWIG_Ruby_MangleStr(VALUE obj)
{
  VALUE stype = rb_iv_get(obj, "@__swigtype__");
  return StringValuePtr(stype);
}

/* Acquire a pointer value */
typedef void (*ruby_owntype)(void*);

SWIGRUNTIME ruby_owntype
SWIG_Ruby_AcquirePtr(VALUE obj, ruby_owntype own) {
  if (obj) {
    ruby_owntype oldown = RDATA(obj)->dfree;
    RDATA(obj)->dfree = own;
    return oldown;
  } else {
    return 0;
  }
}

/* Convert a pointer value */
SWIGRUNTIME int
SWIG_Ruby_ConvertPtrAndOwn(VALUE obj, void **ptr, swig_type_info *ty, int flags, ruby_owntype *own)
{
  char *c;
  swig_cast_info *tc;
  void *vptr = 0;

  /* Grab the pointer */
  if (NIL_P(obj)) {
    *ptr = 0;
    return SWIG_OK;
  } else {
    if (TYPE(obj) != T_DATA) {
      return SWIG_ERROR;
    }
    Data_Get_Struct(obj, void, vptr);
  }
  
  if (own) *own = RDATA(obj)->dfree;
    
  /* Check to see if the input object is giving up ownership
     of the underlying C struct or C++ object.  If so then we
     need to reset the destructor since the Ruby object no 
     longer owns the underlying C++ object.*/ 
  if (flags & SWIG_POINTER_DISOWN) {
    /* Is tracking on for this class? */
    int track = 0;
    if (ty && ty->clientdata) {
      swig_class *sklass = (swig_class *) ty->clientdata;
      track = sklass->trackObjects;
    }
		
    if (track) {
      /* We are tracking objects for this class.  Thus we change the destructor
       * to SWIG_RubyRemoveTracking.  This allows us to
       * remove the mapping from the C++ to Ruby object
       * when the Ruby object is garbage collected.  If we don't
       * do this, then it is possible we will return a reference 
       * to a Ruby object that no longer exists thereby crashing Ruby. */
      RDATA(obj)->dfree = SWIG_RubyRemoveTracking;
    } else {    
      RDATA(obj)->dfree = 0;
    }
  }

  /* Do type-checking if type info was provided */
  if (ty) {
    if (ty->clientdata) {
      if (rb_obj_is_kind_of(obj, ((swig_class *) (ty->clientdata))->klass)) {
        if (vptr == 0) {
          /* The object has already been deleted */
          return SWIG_ObjectPreviouslyDeletedError;
        }
        *ptr = vptr;
        return SWIG_OK;
      }
    }
    if ((c = SWIG_MangleStr(obj)) == NULL) {
      return SWIG_ERROR;
    }
    tc = SWIG_TypeCheck(c, ty);
    if (!tc) {
      return SWIG_ERROR;
    }
    *ptr = SWIG_TypeCast(tc, vptr);
  } else {
    *ptr = vptr;
  }
  
  return SWIG_OK;
}

/* Check convert */
SWIGRUNTIMEINLINE int
SWIG_Ruby_CheckConvert(VALUE obj, swig_type_info *ty)
{
  char *c = SWIG_MangleStr(obj);
  if (!c) return 0;
  return SWIG_TypeCheck(c,ty) != 0;
}

SWIGRUNTIME VALUE
SWIG_Ruby_NewPackedObj(void *ptr, int sz, swig_type_info *type) {
  char result[1024];
  char *r = result;
  if ((2*sz + 1 + strlen(type->name)) > 1000) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r, ptr, sz);
  strcpy(r, type->name);
  return rb_str_new2(result);
}

/* Convert a packed value value */
SWIGRUNTIME int
SWIG_Ruby_ConvertPacked(VALUE obj, void *ptr, int sz, swig_type_info *ty) {
  swig_cast_info *tc;
  const char  *c;

  if (TYPE(obj) != T_STRING) goto type_error;
  c = StringValuePtr(obj);
  /* Pointer values must start with leading underscore */
  if (*c != '_') goto type_error;
  c++;
  c = SWIG_UnpackData(c, ptr, sz);
  if (ty) {
    tc = SWIG_TypeCheck(c, ty);
    if (!tc) goto type_error;
  }
  return SWIG_OK;

 type_error:
  return SWIG_ERROR;
}

SWIGRUNTIME swig_module_info *
SWIG_Ruby_GetModule(void)
{
  VALUE pointer;
  swig_module_info *ret = 0;
  VALUE verbose = rb_gv_get("VERBOSE");

 /* temporarily disable warnings, since the pointer check causes warnings with 'ruby -w' */
  rb_gv_set("VERBOSE", Qfalse);
  
  /* first check if pointer already created */
  pointer = rb_gv_get("$swig_runtime_data_type_pointer" SWIG_RUNTIME_VERSION SWIG_TYPE_TABLE_NAME);
  if (pointer != Qnil) {
    Data_Get_Struct(pointer, swig_module_info, ret);
  }

  /* reinstate warnings */
  rb_gv_set("VERBOSE", verbose);
  return ret;
}

SWIGRUNTIME void 
SWIG_Ruby_SetModule(swig_module_info *pointer)
{
  /* register a new class */
  VALUE cl = rb_define_class("swig_runtime_data", rb_cObject);
  /* create and store the structure pointer to a global variable */
  swig_runtime_data_type_pointer = Data_Wrap_Struct(cl, 0, 0, pointer);
  rb_define_readonly_variable("$swig_runtime_data_type_pointer" SWIG_RUNTIME_VERSION SWIG_TYPE_TABLE_NAME, &swig_runtime_data_type_pointer);
}

/* This function can be used to check whether a proc or method or similarly
   callable function has been passed.  Usually used in a %typecheck, like:

   %typecheck(c_callback_t, precedence=SWIG_TYPECHECK_POINTER) {
        $result = SWIG_Ruby_isCallable( $input );
   }
 */
SWIGINTERN
int SWIG_Ruby_isCallable( VALUE proc )
{
  if ( rb_respond_to( proc, swig_call_id ) == Qtrue )
    return 1;
  return 0;
}

/* This function can be used to check the arity (number of arguments)
   a proc or method can take.  Usually used in a %typecheck.
   Valid arities will be that equal to minimal or those < 0
   which indicate a variable number of parameters at the end.
 */
SWIGINTERN
int SWIG_Ruby_arity( VALUE proc, int minimal )
{
  if ( rb_respond_to( proc, swig_arity_id ) == Qtrue )
    {
      VALUE num = rb_funcall( proc, swig_arity_id, 0 );
      int arity = NUM2INT(num);
      if ( arity < 0 && (arity+1) < -minimal ) return 1;
      if ( arity == minimal ) return 1;
      return 1;
    }
  return 0;
}


#ifdef __cplusplus
}
#endif



#define SWIG_exception_fail(code, msg) do { SWIG_Error(code, msg); SWIG_fail; } while(0) 

#define SWIG_contract_assert(expr, msg) if (!(expr)) { SWIG_Error(SWIG_RuntimeError, msg); SWIG_fail; } else 



/* -------- TYPES TABLE (BEGIN) -------- */

#define SWIGTYPE_p_Buf_tuple_t swig_types[0]
#define SWIGTYPE_p_CdIo_t swig_types[1]
#define SWIGTYPE_p_CdioList_t swig_types[2]
#define SWIGTYPE_p_cdio_read_mode_t swig_types[3]
#define SWIGTYPE_p_char swig_types[4]
#define SWIGTYPE_p_int swig_types[5]
#define SWIGTYPE_p_iso9660_dir_t swig_types[6]
#define SWIGTYPE_p_iso9660_dtime_t swig_types[7]
#define SWIGTYPE_p_iso9660_ltime_t swig_types[8]
#define SWIGTYPE_p_iso9660_pvd_t swig_types[9]
#define SWIGTYPE_p_iso9660_stat_t swig_types[10]
#define SWIGTYPE_p_iso9660_t swig_types[11]
#define SWIGTYPE_p_long swig_types[12]
#define SWIGTYPE_p_unsigned_int swig_types[13]
static swig_type_info *swig_types[15];
static swig_module_info swig_module = {swig_types, 14, 0, 0, 0, 0};
#define SWIG_TypeQuery(name) SWIG_TypeQueryModule(&swig_module, &swig_module, name)
#define SWIG_MangledTypeQuery(name) SWIG_MangledTypeQueryModule(&swig_module, &swig_module, name)

/* -------- TYPES TABLE (END) -------- */

#define SWIG_init    Init_rubyiso9660
#define SWIG_name    "Rubyiso9660"

static VALUE mRubyiso9660;

#define SWIG_RUBY_THREAD_BEGIN_BLOCK
#define SWIG_RUBY_THREAD_END_BLOCK


#define SWIGVERSION 0x010333 
#define SWIG_VERSION SWIGVERSION


#define SWIG_as_voidptr(a) (void *)((const void *)(a)) 
#define SWIG_as_voidptrptr(a) ((void)SWIG_as_voidptr(*a),(void**)(a)) 


/* Includes the header in the wrapper code */
#include <time.h>
#include <cdio/iso9660.h>
#include <cdio/version.h>


#include <limits.h>
#if !defined(SWIG_NO_LLONG_MAX)
# if !defined(LLONG_MAX) && defined(__GNUC__) && defined (__LONG_LONG_MAX__)
#   define LLONG_MAX __LONG_LONG_MAX__
#   define LLONG_MIN (-LLONG_MAX - 1LL)
#   define ULLONG_MAX (LLONG_MAX * 2ULL + 1ULL)
# endif
#endif


  #define SWIG_From_long   LONG2NUM 


/* When libcdio version > 0.76 comes out this won't be needed. */
#include <cdio/version.h>
#if LIBCDIO_VERSION_NUM <= 76

/**< Masks derived from above... */
#undef CDIO_DRIVE_CAP_WRITE_DVD
#define CDIO_DRIVE_CAP_WRITE_DVD (               \
      CDIO_DRIVE_CAP_WRITE_DVD_R                 \
    | CDIO_DRIVE_CAP_WRITE_DVD_PR                \
    | CDIO_DRIVE_CAP_WRITE_DVD_RAM               \
    | CDIO_DRIVE_CAP_WRITE_DVD_RW                \
    | CDIO_DRIVE_CAP_WRITE_DVD_RPW               \
    ) 

/** All the different ways a block/sector can be read. */
typedef enum {
  CDIO_READ_MODE_AUDIO,  /**< CD-DA, audio, Red Book */
  CDIO_READ_MODE_M1F1,   /**< Mode 1 Form 1 */
  CDIO_READ_MODE_M1F2,   /**< Mode 1 Form 2 */
  CDIO_READ_MODE_M2F1,   /**< Mode 2 Form 1 */
  CDIO_READ_MODE_M2F2,   /**< Mode 2 Form 2 */
} cdio_read_mode_t;

/*!
  Reads a number of sectors (AKA blocks).
  
  @param p_buf place to read data into. The caller should make sure
  this location is large enough. See below for size information.
  @param read_mode the kind of "mode" to use in reading.
  @param i_lsn sector to read
  @param i_blocks number of sectors to read
  @return DRIVER_OP_SUCCESS (0) if no error, other (negative) enumerations
  are returned on error.
  
  If read_mode is CDIO_MODE_AUDIO,
    *p_buf should hold at least CDIO_FRAMESIZE_RAW * i_blocks bytes.

  If read_mode is CDIO_MODE_DATA,
    *p_buf should hold at least i_blocks times either ISO_BLOCKSIZE, 
    M1RAW_SECTOR_SIZE or M2F2_SECTOR_SIZE depending on the kind of 
    sector getting read. If you don't know whether you have a Mode 1/2, 
    Form 1/ Form 2/Formless sector best to reserve space for the maximum
    which is M2RAW_SECTOR_SIZE.

  If read_mode is CDIO_MODE_M2F1,
    *p_buf should hold at least M2RAW_SECTOR_SIZE * i_blocks bytes.

  If read_mode is CDIO_MODE_M2F2,
    *p_buf should hold at least CDIO_CD_FRAMESIZE * i_blocks bytes.


*/
driver_return_code_t 
cdio_read_sectors(const CdIo_t *p_cdio, void *p_buf, lsn_t i_lsn, 
                  cdio_read_mode_t read_mode, uint32_t i_blocks)
{
  switch(read_mode) {
  case CDIO_READ_MODE_AUDIO:
    return cdio_read_audio_sectors (p_cdio, p_buf, i_lsn, i_blocks);
  case CDIO_READ_MODE_M1F1:
    return cdio_read_mode1_sectors (p_cdio, p_buf, i_lsn, false, i_blocks);
  case CDIO_READ_MODE_M1F2:
    return cdio_read_mode1_sectors (p_cdio, p_buf, i_lsn, true,  i_blocks);
  case CDIO_READ_MODE_M2F1:
    return cdio_read_mode2_sectors (p_cdio, p_buf, i_lsn, false, i_blocks);
  case CDIO_READ_MODE_M2F2:
    return cdio_read_mode2_sectors (p_cdio, p_buf, i_lsn, true,  i_blocks);
  }
  /* Can't happen. Just to shut up gcc. */
  return DRIVER_OP_ERROR; 
}

driver_return_code_t
cdio_eject_media_drive (const char *psz_drive)
{
  CdIo_t *p_cdio = cdio_open (psz_drive, DRIVER_DEVICE);
  if (p_cdio) {
    return cdio_eject_media(&p_cdio);
  } else {
    return DRIVER_OP_UNINIT;
  }
}
#endif /* LIBCDIO_VERSION_NUM <= 76 */


SWIGINTERNINLINE VALUE
SWIG_From_int  (int value)
{    
  return SWIG_From_long  (value);
}


SWIGINTERN VALUE
SWIG_ruby_failed(void)
{
  return Qnil;
} 


/*@SWIG:/usr/share/swig1.3/ruby/rubyprimtypes.swg,23,%ruby_aux_method@*/
SWIGINTERN VALUE SWIG_AUX_NUM2LONG(VALUE *args)
{
  VALUE obj = args[0];
  VALUE type = TYPE(obj);
  long *res = (long *)(args[1]);
  *res = type == T_FIXNUM ? NUM2LONG(obj) : rb_big2long(obj);
  return obj;
}
/*@SWIG@*/

SWIGINTERN int
SWIG_AsVal_long (VALUE obj, long* val)
{
  VALUE type = TYPE(obj);
  if ((type == T_FIXNUM) || (type == T_BIGNUM)) {
    long v;
    VALUE a[2];
    a[0] = obj;
    a[1] = (VALUE)(&v);
    if (rb_rescue(RUBY_METHOD_FUNC(SWIG_AUX_NUM2LONG), (VALUE)a, RUBY_METHOD_FUNC(SWIG_ruby_failed), 0) != Qnil) {
      if (val) *val = v;
      return SWIG_OK;
    }
  }
  return SWIG_TypeError;
}


SWIGINTERN int
SWIG_AsVal_int (VALUE obj, int *val)
{
  long v;
  int res = SWIG_AsVal_long (obj, &v);
  if (SWIG_IsOK(res)) {
    if ((v < INT_MIN || v > INT_MAX)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = (int)(v);
    }
  }  
  return res;
}


/*@SWIG:/usr/share/swig1.3/ruby/rubyprimtypes.swg,23,%ruby_aux_method@*/
SWIGINTERN VALUE SWIG_AUX_NUM2ULONG(VALUE *args)
{
  VALUE obj = args[0];
  VALUE type = TYPE(obj);
  unsigned long *res = (unsigned long *)(args[1]);
  *res = type == T_FIXNUM ? NUM2ULONG(obj) : rb_big2ulong(obj);
  return obj;
}
/*@SWIG@*/

SWIGINTERN int
SWIG_AsVal_unsigned_SS_long (VALUE obj, unsigned long *val) 
{
  VALUE type = TYPE(obj);
  if ((type == T_FIXNUM) || (type == T_BIGNUM)) {
    unsigned long v;
    VALUE a[2];
    a[0] = obj;
    a[1] = (VALUE)(&v);
    if (rb_rescue(RUBY_METHOD_FUNC(SWIG_AUX_NUM2ULONG), (VALUE)a, RUBY_METHOD_FUNC(SWIG_ruby_failed), 0) != Qnil) {
      if (val) *val = v;
      return SWIG_OK;
    }
  }
  return SWIG_TypeError;
}


SWIGINTERN int
SWIG_AsVal_unsigned_SS_int (VALUE obj, unsigned int *val)
{
  unsigned long v;
  int res = SWIG_AsVal_unsigned_SS_long (obj, &v);
  if (SWIG_IsOK(res)) {
    if ((v > UINT_MAX)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = (unsigned int)(v);
    }
  }  
  return res;
}


SWIGINTERN swig_type_info*
SWIG_pchar_descriptor(void)
{
  static int init = 0;
  static swig_type_info* info = 0;
  if (!init) {
    info = SWIG_TypeQuery("_p_char");
    init = 1;
  }
  return info;
}


SWIGINTERN int
SWIG_AsCharPtrAndSize(VALUE obj, char** cptr, size_t* psize, int *alloc)
{
  if (TYPE(obj) == T_STRING) {
    #if defined(StringValuePtr)
    char *cstr = StringValuePtr(obj); 
    #else
    char *cstr = STR2CSTR(obj);
    #endif
    size_t size = RSTRING_LEN(obj) + 1;
    if (cptr)  {
      if (alloc) {
	if (*alloc == SWIG_NEWOBJ) {
	  *cptr = (char *)memcpy((char *)malloc((size)*sizeof(char)), cstr, sizeof(char)*(size));
	} else {
	  *cptr = cstr;
	  *alloc = SWIG_OLDOBJ;
	}
      }
    }
    if (psize) *psize = size;
    return SWIG_OK;
  } else {
    swig_type_info* pchar_descriptor = SWIG_pchar_descriptor();
    if (pchar_descriptor) {
      void* vptr = 0;
      if (SWIG_ConvertPtr(obj, &vptr, pchar_descriptor, 0) == SWIG_OK) {
	if (cptr) *cptr = (char *)vptr;
	if (psize) *psize = vptr ? (strlen((char*)vptr) + 1) : 0;
	if (alloc) *alloc = SWIG_OLDOBJ;
	return SWIG_OK;
      }
    }
  }  
  return SWIG_TypeError;
}





#ifdef __cplusplus
extern "C" {
#endif
#include "rubyio.h"
#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif
#ifdef HAVE_SYS_TIME_H
# include <sys/time.h>
struct timeval rb_time_timeval(VALUE);
#endif
#ifdef __cplusplus
}
#endif


typedef CdioList_t IsoStatList_t;
typedef iso9660_stat_t IsoStat_t;


typedef struct {
  char   *data;
  size_t i_size;
} Buf_tuple_t;


SWIGINTERNINLINE VALUE 
SWIG_FromCharPtrAndSize(const char* carray, size_t size)
{
  if (carray) {
    if (size > LONG_MAX) {
      swig_type_info* pchar_descriptor = SWIG_pchar_descriptor();
      return pchar_descriptor ? 
	SWIG_NewPointerObj((char *)(carray), pchar_descriptor, 0) : Qnil;
    } else {
      return rb_str_new(carray, (long)(size));
    }
  } else {
    return Qnil;
  }
}


SWIGINTERNINLINE VALUE 
SWIG_FromCharPtr(const char *cptr)
{ 
  return SWIG_FromCharPtrAndSize(cptr, (cptr ? strlen(cptr) : 0));
}


SWIGINTERNINLINE int
SWIG_AsVal_size_t (VALUE obj, size_t *val)
{
  unsigned long v;
  int res = SWIG_AsVal_unsigned_SS_long (obj, val ? &v : 0);
  if (SWIG_IsOK(res) && val) *val = (size_t)(v);
  return res;
}


SWIGINTERNINLINE VALUE
SWIG_From_unsigned_SS_long  (unsigned long value)
{
  return ULONG2NUM(value); 
}


SWIGINTERNINLINE VALUE
SWIG_From_size_t  (size_t value)
{    
  return SWIG_From_unsigned_SS_long  ((unsigned long)(value));
}


Buf_tuple_t 
seek_read (const iso9660_t *p_iso, lsn_t start, ssize_t i_size) 
{
  Buf_tuple_t buf_tuple;
  buf_tuple.data   = calloc(1, i_size);
  buf_tuple.i_size = iso9660_iso_seek_read(p_iso, buf_tuple.data, start, 
					   (i_size) / ISO_BLOCKSIZE);
  return buf_tuple;
 }


iso9660_pvd_t *fs_read_pvd ( const CdIo_t *p_cdio ) {
  static iso9660_pvd_t pvd;
  bool b_ok = iso9660_fs_read_pvd ( p_cdio, &pvd );
  if (!b_ok) return NULL;
  return &pvd;
 }


iso9660_pvd_t *ifs_read_pvd ( const iso9660_t *p_iso ) {
  static iso9660_pvd_t pvd;
  bool b_ok = iso9660_ifs_read_pvd ( p_iso, &pvd );
  if (!b_ok) return NULL;
  return &pvd;
 }


iso9660_dtime_t *
set_dtime ( int year, int mon,  int mday, int hour, int min, int sec)
{
  struct tm tm = { sec,  min, hour, mday, mon-1, year-1900, 0, 0, -1 };
  static iso9660_dtime_t dtime;
  iso9660_set_dtime (&tm, &dtime);
  return &dtime;
}


iso9660_ltime_t *
set_ltime ( int year, int mon,  int mday, int hour, int min, int sec)
 {
   struct tm tm = { sec, min, hour, mday, mon-1, year-1900, 0, 0, -1 };
  static iso9660_ltime_t ldate;
  iso9660_set_ltime (&tm, &ldate);
  return &ldate;
}


SWIGINTERN int
SWIG_AsVal_bool (VALUE obj, bool *val)
{
  if (obj == Qtrue) {
    if (val) *val = true;
    return SWIG_OK;
  } else if (obj == Qfalse) {
    if (val) *val = false;
    return SWIG_OK;
  } else {
    int res = 0;
    if (SWIG_AsVal_int (obj, &res) == SWIG_OK) {    
      if (val) *val = res ? true : false;
      return SWIG_OK;
    }
  }  
  return SWIG_TypeError;
}


struct tm *get_dtime (const iso9660_dtime_t *p_dtime, bool use_localtime) {
  struct tm *p_tm = (struct tm *) calloc(1, sizeof(struct tm));
  if (!iso9660_get_dtime (p_dtime, use_localtime, p_tm)) {
    free(p_tm);
    return NULL;
  }
  return p_tm;
 }


struct tm *get_ltime (const iso9660_ltime_t *p_ltime)
{
  struct tm *p_tm = (struct tm *) calloc(1, sizeof(struct tm));
  if (!iso9660_get_ltime (p_ltime, p_tm)) {
    free(p_tm);
    return NULL;
  }
  return p_tm;
}


char *
name_translate(const char *psz_oldname) {
  char *psz_newname=calloc(sizeof(char), strlen(psz_oldname)+1);
  iso9660_name_translate(psz_oldname, psz_newname);
  return psz_newname;
}


SWIGINTERN int
SWIG_AsVal_unsigned_SS_char (VALUE obj, unsigned char *val)
{
  unsigned long v;
  int res = SWIG_AsVal_unsigned_SS_long (obj, &v);
  if (SWIG_IsOK(res)) {
    if ((v > UCHAR_MAX)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = (unsigned char)(v);
    }
  }  
  return res;
}


char * 
name_translate_ext(const char *psz_oldname, uint8_t i_joliet_level) {
  char *psz_newname=calloc(sizeof(char), strlen(psz_oldname)+1);
  iso9660_name_translate_ext(psz_oldname, psz_newname, i_joliet_level);
  return psz_newname;
}


SWIGINTERN int
SWIG_AsCharArray(VALUE obj, char *val, size_t size)
{ 
  char* cptr = 0; size_t csize = 0; int alloc = SWIG_OLDOBJ;
  int res = SWIG_AsCharPtrAndSize(obj, &cptr, &csize, &alloc);
  if (SWIG_IsOK(res)) {
    if ((csize == size + 1) && cptr && !(cptr[csize-1])) --csize;
    if (csize <= size) {
      if (val) {
	if (csize) memcpy(val, cptr, csize*sizeof(char));
	if (csize < size) memset(val + csize, 0, (size - csize)*sizeof(char));
      }
      if (alloc == SWIG_NEWOBJ) {
	free((char*)cptr);
	res = SWIG_DelNewMask(res);
      }      
      return res;
    }
    if (alloc == SWIG_NEWOBJ) free((char*)cptr);
  }
  return SWIG_TypeError;
}


char *
strncpy_pad(const char src[], size_t len, enum strncpy_pad_check _check) {
  char *dst = calloc(sizeof(char), len+1);
  return iso9660_strncpy_pad(dst, src, len, _check);
}


IsoStatList_t *fs_readdir (CdIo_t *p_cdio, const char psz_path[])
{
  CdioList_t *p_statlist = iso9660_fs_readdir (p_cdio, psz_path, false);
  return p_statlist;
}


IsoStatList_t *ifs_readdir (iso9660_t *p_iso, const char psz_path[])
{
  CdioList_t *p_statlist = iso9660_ifs_readdir (p_iso, psz_path);
  return p_statlist;
}


typedef char * string_or_nil_t;
string_or_nil_t
ifs_get_application_id(iso9660_t *p_iso) {
  char *psz;
  bool ok = iso9660_ifs_get_application_id(p_iso, &psz);
  if (!ok) return NULL;
  return psz;
}


SWIGINTERNINLINE VALUE
SWIG_From_unsigned_SS_char  (unsigned char value)
{    
  return SWIG_From_unsigned_SS_long  (value);
}


string_or_nil_t
ifs_get_preparer_id(iso9660_t *p_iso) {
  char *psz;
  bool ok = iso9660_ifs_get_preparer_id(p_iso, &psz);
  if (!ok) return NULL;
  return psz;
}


string_or_nil_t
ifs_get_publisher_id(iso9660_t *p_iso) {
  char *psz;
  bool ok = iso9660_ifs_get_publisher_id(p_iso, &psz);
  if (!ok) return NULL;
  return psz;
}


char *
ifs_get_system_id(iso9660_t *p_iso) {
  char *psz;
  bool ok = iso9660_ifs_get_system_id(p_iso, &psz);
  if (!ok) return NULL;
  return psz;
}


char *
ifs_get_volume_id(iso9660_t *p_iso) {
  char *psz;
  bool ok = iso9660_ifs_get_volume_id(p_iso, &psz);
  if (!ok) return NULL;
  return psz;
}


string_or_nil_t
ifs_get_volumeset_id(iso9660_t *p_iso) {
  char *psz;
  bool ok = iso9660_ifs_get_volumeset_id(p_iso, &psz);
  if (!ok) return NULL;
  return psz;
}


SWIGINTERNINLINE VALUE
SWIG_From_unsigned_SS_int  (unsigned int value)
{    
  return SWIG_From_unsigned_SS_long  (value);
}

SWIGINTERN VALUE
_wrap_cdio_read_sectors(int argc, VALUE *argv, VALUE self) {
  CdIo_t *arg1 = (CdIo_t *) 0 ;
  void *arg2 = (void *) 0 ;
  lsn_t arg3 ;
  cdio_read_mode_t arg4 ;
  unsigned int arg5 ;
  driver_return_code_t result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  int val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  unsigned int val5 ;
  int ecode5 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 5) || (argc > 5)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 5)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_CdIo_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "CdIo_t const *","cdio_read_sectors", 1, argv[0] )); 
  }
  arg1 = (CdIo_t *)(argp1);
  res2 = SWIG_ConvertPtr(argv[1],SWIG_as_voidptrptr(&arg2), 0, 0);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), Ruby_Format_TypeError( "", "void *","cdio_read_sectors", 2, argv[1] )); 
  }
  ecode3 = SWIG_AsVal_int(argv[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "lsn_t","cdio_read_sectors", 3, argv[2] ));
  } 
  arg3 = (lsn_t)(val3);
  ecode4 = SWIG_AsVal_int(argv[3], &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), Ruby_Format_TypeError( "", "cdio_read_mode_t","cdio_read_sectors", 4, argv[3] ));
  } 
  arg4 = (cdio_read_mode_t)(val4);
  ecode5 = SWIG_AsVal_unsigned_SS_int(argv[4], &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), Ruby_Format_TypeError( "", "unsigned int","cdio_read_sectors", 5, argv[4] ));
  } 
  arg5 = (unsigned int)(val5);
  result = (driver_return_code_t)cdio_read_sectors((CdIo_t const *)arg1,arg2,arg3,arg4,arg5);
  vresult = SWIG_From_long((long)(result));
  return vresult;
fail:
  return Qnil;
}


SWIGINTERN VALUE
_wrap_cdio_eject_media_drive(int argc, VALUE *argv, VALUE self) {
  char *arg1 = (char *) 0 ;
  driver_return_code_t result;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_AsCharPtrAndSize(argv[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "char const *","cdio_eject_media_drive", 1, argv[0] ));
  }
  arg1 = (char *)(buf1);
  result = (driver_return_code_t)cdio_eject_media_drive((char const *)arg1);
  vresult = SWIG_From_long((long)(result));
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return vresult;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.open_iso

  call-seq:
    open_iso(psz_path) -> iso9660_t

open_iso(path)
 Open an ISO 9660 image for reading. Maybe in the future we will have
 mode. None is returned on error.
.
*/
SWIGINTERN VALUE
_wrap_open_iso(int argc, VALUE *argv, VALUE self) {
  char *arg1 = (char *) 0 ;
  iso9660_t *result = 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_AsCharPtrAndSize(argv[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "char const *","iso9660_open", 1, argv[0] ));
  }
  arg1 = (char *)(buf1);
  result = (iso9660_t *)iso9660_open((char const *)arg1);
  vresult = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return vresult;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.open_ext

  call-seq:
    open_ext(psz_path, iso_extension_mask) -> iso9660_t

Open an ISO 9660 image for reading allowing various ISO 9660
 extensions.  Maybe in the future we will have a mode. None is
 returned on error..
*/
SWIGINTERN VALUE
_wrap_open_ext(int argc, VALUE *argv, VALUE self) {
  char *arg1 = (char *) 0 ;
  iso_extension_mask_t arg2 ;
  iso9660_t *result = 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 2) || (argc > 2)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 2)",argc); SWIG_fail;
  }
  res1 = SWIG_AsCharPtrAndSize(argv[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "char const *","iso9660_open_ext", 1, argv[0] ));
  }
  arg1 = (char *)(buf1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(argv[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "iso_extension_mask_t","iso9660_open_ext", 2, argv[1] ));
  } 
  arg2 = (iso_extension_mask_t)(val2);
  result = (iso9660_t *)iso9660_open_ext((char const *)arg1,arg2);
  vresult = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return vresult;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.open_fuzzy

  call-seq:
    open_fuzzy(psz_path, i_fuzz) -> iso9660_t

Open an ISO 9660 image for reading with some tolerence for positioning
of the ISO9660 image. We scan for ISO_STANDARD_ID and use that to set
the eventual offset to adjust by (as long as that is <= i_fuzz).

Maybe in the future we will have a mode. None is returned on error.

see iso9660_open.
*/
SWIGINTERN VALUE
_wrap_open_fuzzy(int argc, VALUE *argv, VALUE self) {
  char *arg1 = (char *) 0 ;
  unsigned int arg2 ;
  iso9660_t *result = 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 2) || (argc > 2)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 2)",argc); SWIG_fail;
  }
  res1 = SWIG_AsCharPtrAndSize(argv[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "char const *","iso9660_open_fuzzy", 1, argv[0] ));
  }
  arg1 = (char *)(buf1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(argv[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "unsigned int","iso9660_open_fuzzy", 2, argv[1] ));
  } 
  arg2 = (unsigned int)(val2);
  result = (iso9660_t *)iso9660_open_fuzzy((char const *)arg1,arg2);
  vresult = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return vresult;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.iso9660_open_fuzzy_ext

  call-seq:
    iso9660_open_fuzzy_ext(psz_path, iso_extension_mask, i_fuzz) -> iso9660_t

Open an ISO 9660 image for reading with some tolerence for positioning
of the ISO9660 image. We scan for ISO_STANDARD_ID and use that to set
the eventual offset to adjust by (as long as that is <= i_fuzz).

Maybe in the future we will have a mode. None is returned on error.

see open_iso
.
*/
SWIGINTERN VALUE
_wrap_iso9660_open_fuzzy_ext(int argc, VALUE *argv, VALUE self) {
  char *arg1 = (char *) 0 ;
  iso_extension_mask_t arg2 ;
  unsigned int arg3 ;
  iso9660_t *result = 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  unsigned int val3 ;
  int ecode3 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 3) || (argc > 3)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 3)",argc); SWIG_fail;
  }
  res1 = SWIG_AsCharPtrAndSize(argv[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "char const *","iso9660_open_fuzzy_ext", 1, argv[0] ));
  }
  arg1 = (char *)(buf1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(argv[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "iso_extension_mask_t","iso9660_open_fuzzy_ext", 2, argv[1] ));
  } 
  arg2 = (iso_extension_mask_t)(val2);
  ecode3 = SWIG_AsVal_unsigned_SS_int(argv[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "unsigned int","iso9660_open_fuzzy_ext", 3, argv[2] ));
  } 
  arg3 = (unsigned int)(val3);
  result = (iso9660_t *)iso9660_open_fuzzy_ext((char const *)arg1,arg2,arg3);
  vresult = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return vresult;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.ifs_fuzzy_read_superblock

  call-seq:
    ifs_fuzzy_read_superblock(p_iso, iso_extension_mask, i_fuzz) -> bool

Read the Super block of an ISO 9660 image but determine framesize
and datastart and a possible additional offset. Generally here we are
not reading an ISO 9660 image but a CD-Image which contains an ISO 9660
filesystem.
.
*/
SWIGINTERN VALUE
_wrap_ifs_fuzzy_read_superblock(int argc, VALUE *argv, VALUE self) {
  iso9660_t *arg1 = (iso9660_t *) 0 ;
  iso_extension_mask_t arg2 ;
  unsigned int arg3 ;
  bool result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  unsigned int val3 ;
  int ecode3 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 3) || (argc > 3)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 3)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_t *","iso9660_ifs_fuzzy_read_superblock", 1, argv[0] )); 
  }
  arg1 = (iso9660_t *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(argv[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "iso_extension_mask_t","iso9660_ifs_fuzzy_read_superblock", 2, argv[1] ));
  } 
  arg2 = (iso_extension_mask_t)(val2);
  ecode3 = SWIG_AsVal_unsigned_SS_int(argv[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "unsigned int","iso9660_ifs_fuzzy_read_superblock", 3, argv[2] ));
  } 
  arg3 = (unsigned int)(val3);
  result = (bool)iso9660_ifs_fuzzy_read_superblock(arg1,arg2,arg3);
  vresult = (result != 0) ? Qtrue : Qfalse;
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.close

  call-seq:
    close(p_iso) -> bool

Close previously opened ISO 9660 image.
True is unconditionally returned. If there was an error false would
be returned..
*/
SWIGINTERN VALUE
_wrap_close(int argc, VALUE *argv, VALUE self) {
  iso9660_t *arg1 = (iso9660_t *) 0 ;
  bool result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_t *","iso9660_close", 1, argv[0] )); 
  }
  arg1 = (iso9660_t *)(argp1);
  result = (bool)iso9660_close(arg1);
  vresult = (result != 0) ? Qtrue : Qfalse;
  return vresult;
fail:
  return Qnil;
}



/*
  Document-class: Rubyiso9660::Buf_tuple_t

  call-seq:


Close previously opened ISO 9660 image.
True is unconditionally returned. If there was an error false would
be returned..
*/
swig_class cBuf_tuple_t;


/*
  Document-method: Rubyiso9660::Buf_tuple_t.data

  call-seq:
    data -> char

Close previously opened ISO 9660 image.
True is unconditionally returned. If there was an error false would
be returned..
*/

/*
  Document-method: Rubyiso9660::Buf_tuple_t.data=

  call-seq:
    data=(x) -> char

Close previously opened ISO 9660 image.
True is unconditionally returned. If there was an error false would
be returned..
*/
SWIGINTERN VALUE
_wrap_Buf_tuple_t_data_set(int argc, VALUE *argv, VALUE self) {
  Buf_tuple_t *arg1 = (Buf_tuple_t *) 0 ;
  char *arg2 = (char *) 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_Buf_tuple_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "Buf_tuple_t *","data", 1, self )); 
  }
  arg1 = (Buf_tuple_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(argv[0], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), Ruby_Format_TypeError( "", "char *","data", 2, argv[0] ));
  }
  arg2 = (char *)(buf2);
  if (arg1->data) free((char*)arg1->data);
  if (arg2) {
    size_t size = strlen((const char *)(arg2)) + 1;
    arg1->data = (char *)(char *)memcpy((char *)malloc((size)*sizeof(char)), (const char *)(arg2), sizeof(char)*(size));
  } else {
    arg1->data = 0;
  }
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return Qnil;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return Qnil;
}


SWIGINTERN VALUE
_wrap_Buf_tuple_t_data_get(int argc, VALUE *argv, VALUE self) {
  Buf_tuple_t *arg1 = (Buf_tuple_t *) 0 ;
  char *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 0) || (argc > 0)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_Buf_tuple_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "Buf_tuple_t *","data", 1, self )); 
  }
  arg1 = (Buf_tuple_t *)(argp1);
  result = (char *) ((arg1)->data);
  vresult = SWIG_FromCharPtr((const char *)result);
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660::Buf_tuple_t.i_size

  call-seq:
    i_size -> size_t

Close previously opened ISO 9660 image.
True is unconditionally returned. If there was an error false would
be returned..
*/

/*
  Document-method: Rubyiso9660::Buf_tuple_t.i_size=

  call-seq:
    i_size=(x) -> size_t

Close previously opened ISO 9660 image.
True is unconditionally returned. If there was an error false would
be returned..
*/
SWIGINTERN VALUE
_wrap_Buf_tuple_t_i_size_set(int argc, VALUE *argv, VALUE self) {
  Buf_tuple_t *arg1 = (Buf_tuple_t *) 0 ;
  size_t arg2 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_Buf_tuple_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "Buf_tuple_t *","i_size", 1, self )); 
  }
  arg1 = (Buf_tuple_t *)(argp1);
  ecode2 = SWIG_AsVal_size_t(argv[0], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "size_t","i_size", 2, argv[0] ));
  } 
  arg2 = (size_t)(val2);
  if (arg1) (arg1)->i_size = arg2;
  
  return Qnil;
fail:
  return Qnil;
}


SWIGINTERN VALUE
_wrap_Buf_tuple_t_i_size_get(int argc, VALUE *argv, VALUE self) {
  Buf_tuple_t *arg1 = (Buf_tuple_t *) 0 ;
  size_t result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 0) || (argc > 0)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(self, &argp1,SWIGTYPE_p_Buf_tuple_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "Buf_tuple_t *","i_size", 1, self )); 
  }
  arg1 = (Buf_tuple_t *)(argp1);
  result =  ((arg1)->i_size);
  vresult = SWIG_From_size_t((size_t)(result));
  return vresult;
fail:
  return Qnil;
}


#ifdef HAVE_RB_DEFINE_ALLOC_FUNC
SWIGINTERN VALUE
_wrap_Buf_tuple_t_allocate(VALUE self) {
#else
  SWIGINTERN VALUE
  _wrap_Buf_tuple_t_allocate(int argc, VALUE *argv, VALUE self) {
#endif
    
    
    VALUE vresult = SWIG_NewClassInstance(self, SWIGTYPE_p_Buf_tuple_t);
#ifndef HAVE_RB_DEFINE_ALLOC_FUNC
    rb_obj_call_init(vresult, argc, argv);
#endif
    return vresult;
  }
  


/*
  Document-method: Rubyiso9660::Buf_tuple_t.new

  call-seq:


Return true if ISO 9660 image has extended attrributes (XA)..
*/
SWIGINTERN VALUE
_wrap_new_Buf_tuple_t(int argc, VALUE *argv, VALUE self) {
  Buf_tuple_t *result = 0 ;
  
  if ((argc < 0) || (argc > 0)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 0)",argc); SWIG_fail;
  }
  result = (Buf_tuple_t *)(Buf_tuple_t *) calloc(1, sizeof(Buf_tuple_t));DATA_PTR(self) = result;
  
  return self;
fail:
  return Qnil;
}


SWIGINTERN void
free_Buf_tuple_t(Buf_tuple_t *arg1) {
    free((char *) arg1);
}


/*
  Document-method: Rubyiso9660.seek_read

  call-seq:
    seek_read(p_iso, start, i_size) -> Buf_tuple_t

Seek to a position and then read n bytes. (buffer, size) are
 returned..
*/
SWIGINTERN VALUE
_wrap_seek_read(int argc, VALUE *argv, VALUE self) {
  iso9660_t *arg1 = (iso9660_t *) 0 ;
  lsn_t arg2 ;
  ssize_t arg3 ;
  Buf_tuple_t result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  long val3 ;
  int ecode3 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 3) || (argc > 3)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 3)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_t const *","seek_read", 1, argv[0] )); 
  }
  arg1 = (iso9660_t *)(argp1);
  ecode2 = SWIG_AsVal_int(argv[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "lsn_t","seek_read", 2, argv[1] ));
  } 
  arg2 = (lsn_t)(val2);
  ecode3 = SWIG_AsVal_long(argv[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "ssize_t","seek_read", 3, argv[2] ));
  } 
  arg3 = (ssize_t)(val3);
  result = seek_read((iso9660_t const *)arg1,arg2,arg3);
  {
    if (!(&result)->data) 
    return Qnil;
    else {
      VALUE data_tuple = rb_ary_new();
      rb_ary_push(data_tuple, INT2NUM((&result)->i_size)); 
      rb_ary_push(data_tuple, rb_str_new((&result)->data, (&result)->i_size)); 
      free((&result)->data);
      return data_tuple;
    }
  }
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.fs_read_pvd

  call-seq:
    fs_read_pvd(p_cdio) -> iso9660_pvd_t

Read the Primary Volume Descriptor for a CD.
None  is returned if there was an error..
*/
SWIGINTERN VALUE
_wrap_fs_read_pvd(int argc, VALUE *argv, VALUE self) {
  CdIo_t *arg1 = (CdIo_t *) 0 ;
  iso9660_pvd_t *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_CdIo_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "CdIo_t const *","fs_read_pvd", 1, argv[0] )); 
  }
  arg1 = (CdIo_t *)(argp1);
  result = (iso9660_pvd_t *)fs_read_pvd((CdIo_t const *)arg1);
  vresult = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_iso9660_pvd_t, 0 |  0 );
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.ifs_read_pvd

  call-seq:
    ifs_read_pvd(p_iso) -> iso9660_pvd_t

Read the Primary Volume Descriptor for an ISO 9660 image.
None is returned if there was an error..
*/
SWIGINTERN VALUE
_wrap_ifs_read_pvd(int argc, VALUE *argv, VALUE self) {
  iso9660_t *arg1 = (iso9660_t *) 0 ;
  iso9660_pvd_t *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_t const *","ifs_read_pvd", 1, argv[0] )); 
  }
  arg1 = (iso9660_t *)(argp1);
  result = (iso9660_pvd_t *)ifs_read_pvd((iso9660_t const *)arg1);
  vresult = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_iso9660_pvd_t, 0 |  0 );
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.fs_read_superblock

  call-seq:
    fs_read_superblock(p_cdio, iso_extension_mask) -> bool

Read the Super block of an ISO 9660 image. This is the 
Primary Volume Descriptor (PVD) and perhaps a Supplemental Volume 
Descriptor if (Joliet) extensions are acceptable..
*/
SWIGINTERN VALUE
_wrap_fs_read_superblock(int argc, VALUE *argv, VALUE self) {
  CdIo_t *arg1 = (CdIo_t *) 0 ;
  iso_extension_mask_t arg2 ;
  bool result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 2) || (argc > 2)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 2)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_CdIo_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "CdIo_t *","iso9660_fs_read_superblock", 1, argv[0] )); 
  }
  arg1 = (CdIo_t *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(argv[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "iso_extension_mask_t","iso9660_fs_read_superblock", 2, argv[1] ));
  } 
  arg2 = (iso_extension_mask_t)(val2);
  result = (bool)iso9660_fs_read_superblock(arg1,arg2);
  vresult = (result != 0) ? Qtrue : Qfalse;
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.ifs_read_superblock

  call-seq:
    ifs_read_superblock(p_iso, iso_extension_mask) -> bool

Read the Super block of an ISO 9660 image. This is the 
 Primary Volume Descriptor (PVD) and perhaps a Supplemental Volume 
 Descriptor if (Joliet) extensions are acceptable..
*/
SWIGINTERN VALUE
_wrap_ifs_read_superblock(int argc, VALUE *argv, VALUE self) {
  iso9660_t *arg1 = (iso9660_t *) 0 ;
  iso_extension_mask_t arg2 ;
  bool result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 2) || (argc > 2)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 2)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_t *","iso9660_ifs_read_superblock", 1, argv[0] )); 
  }
  arg1 = (iso9660_t *)(argp1);
  ecode2 = SWIG_AsVal_unsigned_SS_int(argv[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "iso_extension_mask_t","iso9660_ifs_read_superblock", 2, argv[1] ));
  } 
  arg2 = (iso_extension_mask_t)(val2);
  result = (bool)iso9660_ifs_read_superblock(arg1,arg2);
  vresult = (result != 0) ? Qtrue : Qfalse;
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.set_dtime

  call-seq:
    set_dtime(year, mon, mday, hour, min, sec) -> iso9660_dtime_t

Set time in format used in ISO 9660 directory index record.
*/
SWIGINTERN VALUE
_wrap_set_dtime(int argc, VALUE *argv, VALUE self) {
  int arg1 ;
  int arg2 ;
  int arg3 ;
  int arg4 ;
  int arg5 ;
  int arg6 ;
  iso9660_dtime_t *result = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 6) || (argc > 6)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 6)",argc); SWIG_fail;
  }
  ecode1 = SWIG_AsVal_int(argv[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), Ruby_Format_TypeError( "", "int","set_dtime", 1, argv[0] ));
  } 
  arg1 = (int)(val1);
  ecode2 = SWIG_AsVal_int(argv[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","set_dtime", 2, argv[1] ));
  } 
  arg2 = (int)(val2);
  ecode3 = SWIG_AsVal_int(argv[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "int","set_dtime", 3, argv[2] ));
  } 
  arg3 = (int)(val3);
  ecode4 = SWIG_AsVal_int(argv[3], &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), Ruby_Format_TypeError( "", "int","set_dtime", 4, argv[3] ));
  } 
  arg4 = (int)(val4);
  ecode5 = SWIG_AsVal_int(argv[4], &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), Ruby_Format_TypeError( "", "int","set_dtime", 5, argv[4] ));
  } 
  arg5 = (int)(val5);
  ecode6 = SWIG_AsVal_int(argv[5], &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), Ruby_Format_TypeError( "", "int","set_dtime", 6, argv[5] ));
  } 
  arg6 = (int)(val6);
  result = (iso9660_dtime_t *)set_dtime(arg1,arg2,arg3,arg4,arg5,arg6);
  vresult = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_iso9660_dtime_t, 0 |  0 );
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.set_ltime

  call-seq:
    set_ltime(year, mon, mday, hour, min, sec) -> iso9660_ltime_t

Set 'long' time in format used in ISO 9660 primary volume descriptor.
*/
SWIGINTERN VALUE
_wrap_set_ltime(int argc, VALUE *argv, VALUE self) {
  int arg1 ;
  int arg2 ;
  int arg3 ;
  int arg4 ;
  int arg5 ;
  int arg6 ;
  iso9660_ltime_t *result = 0 ;
  int val1 ;
  int ecode1 = 0 ;
  int val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  int val4 ;
  int ecode4 = 0 ;
  int val5 ;
  int ecode5 = 0 ;
  int val6 ;
  int ecode6 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 6) || (argc > 6)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 6)",argc); SWIG_fail;
  }
  ecode1 = SWIG_AsVal_int(argv[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), Ruby_Format_TypeError( "", "int","set_ltime", 1, argv[0] ));
  } 
  arg1 = (int)(val1);
  ecode2 = SWIG_AsVal_int(argv[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "int","set_ltime", 2, argv[1] ));
  } 
  arg2 = (int)(val2);
  ecode3 = SWIG_AsVal_int(argv[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "int","set_ltime", 3, argv[2] ));
  } 
  arg3 = (int)(val3);
  ecode4 = SWIG_AsVal_int(argv[3], &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), Ruby_Format_TypeError( "", "int","set_ltime", 4, argv[3] ));
  } 
  arg4 = (int)(val4);
  ecode5 = SWIG_AsVal_int(argv[4], &val5);
  if (!SWIG_IsOK(ecode5)) {
    SWIG_exception_fail(SWIG_ArgError(ecode5), Ruby_Format_TypeError( "", "int","set_ltime", 5, argv[4] ));
  } 
  arg5 = (int)(val5);
  ecode6 = SWIG_AsVal_int(argv[5], &val6);
  if (!SWIG_IsOK(ecode6)) {
    SWIG_exception_fail(SWIG_ArgError(ecode6), Ruby_Format_TypeError( "", "int","set_ltime", 6, argv[5] ));
  } 
  arg6 = (int)(val6);
  result = (iso9660_ltime_t *)set_ltime(arg1,arg2,arg3,arg4,arg5,arg6);
  vresult = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_iso9660_ltime_t, 0 |  0 );
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.get_dtime

  call-seq:
    get_dtime(p_dtime, use_localtime) -> struct tm

Get Unix time structure from format use in an ISO 9660 directory index 
record. Even though tm_wday and tm_yday fields are not explicitly in
idr_date, they are calculated from the other fields.

If tm is to reflect the localtime, set 'use_localtime' true, otherwise
tm will reported in GMT..
*/
SWIGINTERN VALUE
_wrap_get_dtime(int argc, VALUE *argv, VALUE self) {
  iso9660_dtime_t *arg1 = (iso9660_dtime_t *) 0 ;
  bool arg2 ;
  struct tm *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  bool val2 ;
  int ecode2 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 2) || (argc > 2)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 2)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_dtime_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_dtime_t const *","get_dtime", 1, argv[0] )); 
  }
  arg1 = (iso9660_dtime_t *)(argp1);
  ecode2 = SWIG_AsVal_bool(argv[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "bool","get_dtime", 2, argv[1] ));
  } 
  arg2 = (bool)(val2);
  result = (struct tm *)get_dtime((iso9660_dtime_t const *)arg1,arg2);
  {
    struct tm *p_tm = result;
    
    if (result) {
      VALUE resultobj = rb_hash_new();
      rb_hash_aset(resultobj, rb_str_new2("year"),
        INT2NUM(p_tm->tm_year+1900));
      rb_hash_aset(resultobj, rb_str_new2("month"),
        INT2NUM(p_tm->tm_mon+1));
      rb_hash_aset(resultobj, rb_str_new2("mday"),
        INT2NUM(p_tm->tm_mday));
      rb_hash_aset(resultobj, rb_str_new2("hour"),
        INT2NUM(p_tm->tm_hour));
      rb_hash_aset(resultobj, rb_str_new2("min"),
        INT2NUM(p_tm->tm_min));
      rb_hash_aset(resultobj, rb_str_new2("sec"),
        INT2NUM(p_tm->tm_sec));
      rb_hash_aset(resultobj, rb_str_new2("wday"),
        INT2NUM((p_tm->tm_wday-1))%7);
      rb_hash_aset(resultobj, rb_str_new2("isdst"),
        INT2NUM((p_tm->tm_isdst)));
      free (p_tm);
      return resultobj;
    }
  }
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.get_ltime

  call-seq:
    get_ltime(p_ltime) -> struct tm

Get 'long' time in format used in ISO 9660 primary volume descriptor
 from a Unix time structure..
*/
SWIGINTERN VALUE
_wrap_get_ltime(int argc, VALUE *argv, VALUE self) {
  iso9660_ltime_t *arg1 = (iso9660_ltime_t *) 0 ;
  struct tm *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_ltime_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_ltime_t const *","get_ltime", 1, argv[0] )); 
  }
  arg1 = (iso9660_ltime_t *)(argp1);
  result = (struct tm *)get_ltime((iso9660_ltime_t const *)arg1);
  {
    struct tm *p_tm = result;
    
    if (result) {
      VALUE resultobj = rb_hash_new();
      rb_hash_aset(resultobj, rb_str_new2("year"),
        INT2NUM(p_tm->tm_year+1900));
      rb_hash_aset(resultobj, rb_str_new2("month"),
        INT2NUM(p_tm->tm_mon+1));
      rb_hash_aset(resultobj, rb_str_new2("mday"),
        INT2NUM(p_tm->tm_mday));
      rb_hash_aset(resultobj, rb_str_new2("hour"),
        INT2NUM(p_tm->tm_hour));
      rb_hash_aset(resultobj, rb_str_new2("min"),
        INT2NUM(p_tm->tm_min));
      rb_hash_aset(resultobj, rb_str_new2("sec"),
        INT2NUM(p_tm->tm_sec));
      rb_hash_aset(resultobj, rb_str_new2("wday"),
        INT2NUM((p_tm->tm_wday-1))%7);
      rb_hash_aset(resultobj, rb_str_new2("isdst"),
        INT2NUM((p_tm->tm_isdst)));
      free (p_tm);
      return resultobj;
    }
  }
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.dchar?

  call-seq:
    dchar?(c) -> bool

 Return true if c is a DCHAR - a character that can appear in an an
 ISO-9600 level 1 directory name. These are the ASCII capital
 letters A-Z, the digits 0-9 and an underscore..
*/
SWIGINTERN VALUE
_wrap_dcharq___(int argc, VALUE *argv, VALUE self) {
  int arg1 ;
  bool result;
  int val1 ;
  int ecode1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  ecode1 = SWIG_AsVal_int(argv[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), Ruby_Format_TypeError( "", "int","iso9660_isdchar", 1, argv[0] ));
  } 
  arg1 = (int)(val1);
  result = (bool)iso9660_isdchar(arg1);
  vresult = (result != 0) ? Qtrue : Qfalse;
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.achar?

  call-seq:
    achar?(c) -> bool

Return true if c is an ACHAR - 
 These are the DCHAR's plus some ASCII symbols including the space 
 symbol..
*/
SWIGINTERN VALUE
_wrap_acharq___(int argc, VALUE *argv, VALUE self) {
  int arg1 ;
  bool result;
  int val1 ;
  int ecode1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  ecode1 = SWIG_AsVal_int(argv[0], &val1);
  if (!SWIG_IsOK(ecode1)) {
    SWIG_exception_fail(SWIG_ArgError(ecode1), Ruby_Format_TypeError( "", "int","iso9660_isachar", 1, argv[0] ));
  } 
  arg1 = (int)(val1);
  result = (bool)iso9660_isachar(arg1);
  vresult = (result != 0) ? Qtrue : Qfalse;
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.name_translate

  call-seq:
    name_translate(psz_oldname) -> char

Convert an ISO-9660 file name that stored in a directory entry into 
 what's usually listed as the file name in a listing.
 Lowercase name, and remove trailing ;1's or .;1's and
 turn the other ;'s into version numbers.

 @param psz_oldname the ISO-9660 filename to be translated.
 @param psz_newname returned string. The caller allocates this and
 it should be at least the size of psz_oldname.
 @return length of the translated string is returned..
*/
SWIGINTERN VALUE
_wrap_name_translate(int argc, VALUE *argv, VALUE self) {
  char *arg1 = (char *) 0 ;
  char *result = 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_AsCharPtrAndSize(argv[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "char const *","name_translate", 1, argv[0] ));
  }
  arg1 = (char *)(buf1);
  result = (char *)name_translate((char const *)arg1);
  vresult = SWIG_FromCharPtr((const char *)result);
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  free((char*)result);
  return vresult;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.name_translate_ext

  call-seq:
    name_translate_ext(psz_oldname, i_joliet_level) -> char

Convert an ISO-9660 file name that stored in a directory entry into
 what's usually listed as the file name in a listing.  Lowercase
 name if no Joliet Extension interpretation. Remove trailing ;1's or
 .;1's and turn the other ;'s into version numbers.

 @param psz_oldname the ISO-9660 filename to be translated.
 @param psz_newname returned string. The caller allocates this and
 it should be at least the size of psz_oldname.
 @param i_joliet_level 0 if not using Joliet Extension. Otherwise the
 Joliet level.
 @return length of the translated string is returned. It will be no greater
 than the length of psz_oldname..
*/
SWIGINTERN VALUE
_wrap_name_translate_ext(int argc, VALUE *argv, VALUE self) {
  char *arg1 = (char *) 0 ;
  unsigned char arg2 ;
  char *result = 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  unsigned char val2 ;
  int ecode2 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 2) || (argc > 2)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 2)",argc); SWIG_fail;
  }
  res1 = SWIG_AsCharPtrAndSize(argv[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "char const *","name_translate_ext", 1, argv[0] ));
  }
  arg1 = (char *)(buf1);
  ecode2 = SWIG_AsVal_unsigned_SS_char(argv[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "unsigned char","name_translate_ext", 2, argv[1] ));
  } 
  arg2 = (unsigned char)(val2);
  result = (char *)name_translate_ext((char const *)arg1,arg2);
  vresult = SWIG_FromCharPtr((const char *)result);
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  free((char*)result);
  return vresult;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.strncpy_pad

  call-seq:
    strncpy_pad(src, len, _check) -> char

Pad string src with spaces to size len and copy this to dst. If
 en is less than the length of src, dst will be truncated to the
 first len characters of src.

 src can also be scanned to see if it contains only ACHARs, DCHARs, 
 7-bit ASCII chars depending on the enumeration _check.

 In addition to getting changed, dst is the return value.
 Note: this string might not be NULL terminated..
*/
SWIGINTERN VALUE
_wrap_strncpy_pad(int argc, VALUE *argv, VALUE self) {
  char *arg1 ;
  size_t arg2 ;
  enum strncpy_pad_check arg3 ;
  char *result = 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  size_t val2 ;
  int ecode2 = 0 ;
  int val3 ;
  int ecode3 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 3) || (argc > 3)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 3)",argc); SWIG_fail;
  }
  res1 = SWIG_AsCharPtrAndSize(argv[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "char const []","strncpy_pad", 1, argv[0] ));
  }
  arg1 = (char *)(buf1);
  ecode2 = SWIG_AsVal_size_t(argv[1], &val2);
  if (!SWIG_IsOK(ecode2)) {
    SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "size_t","strncpy_pad", 2, argv[1] ));
  } 
  arg2 = (size_t)(val2);
  ecode3 = SWIG_AsVal_int(argv[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "enum strncpy_pad_check","strncpy_pad", 3, argv[2] ));
  } 
  arg3 = (enum strncpy_pad_check)(val3);
  result = (char *)strncpy_pad((char const (*))arg1,arg2,arg3);
  vresult = SWIG_FromCharPtr((const char *)result);
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  free((char*)result);
  return vresult;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.dirname_valid?

  call-seq:
    dirname_valid?(psz_path) -> bool

Check that psz_path is a valid ISO-9660 directory name.

 A valid directory name should not start out with a slash (/), 
 dot (.) or null byte, should be less than 37 characters long, 
 have no more than 8 characters in a directory component 
 which is separated by a /, and consist of only DCHARs. 

 True is returned if psz_path is valid..
*/
SWIGINTERN VALUE
_wrap_dirname_validq___(int argc, VALUE *argv, VALUE self) {
  char *arg1 ;
  bool result;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_AsCharPtrAndSize(argv[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "char const []","iso9660_dirname_valid_p", 1, argv[0] ));
  }
  arg1 = (char *)(buf1);
  result = (bool)iso9660_dirname_valid_p((char const (*))arg1);
  vresult = (result != 0) ? Qtrue : Qfalse;
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return vresult;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.pathname_isofy

  call-seq:
    pathname_isofy(psz_path, i_version=1) -> char

Take psz_path and a version number and turn that into a ISO-9660
pathname.  (That's just the pathname followed by ';' and the version
number. For example, mydir/file.ext -> MYDIR/FILE.EXT;1 for version
1. The resulting ISO-9660 pathname is returned..
*/
SWIGINTERN VALUE
_wrap_pathname_isofy(int argc, VALUE *argv, VALUE self) {
  char *arg1 ;
  unsigned int arg2 = (unsigned int) 1 ;
  char *result = 0 ;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  unsigned int val2 ;
  int ecode2 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 2)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_AsCharPtrAndSize(argv[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "char const []","iso9660_pathname_isofy", 1, argv[0] ));
  }
  arg1 = (char *)(buf1);
  if (argc > 1) {
    ecode2 = SWIG_AsVal_unsigned_SS_int(argv[1], &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), Ruby_Format_TypeError( "", "unsigned int","iso9660_pathname_isofy", 2, argv[1] ));
    } 
    arg2 = (unsigned int)(val2);
  }
  result = (char *)iso9660_pathname_isofy((char const (*))arg1,arg2);
  vresult = SWIG_FromCharPtr((const char *)result);
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  free((char*)result);
  return vresult;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.pathname_valid?

  call-seq:
    pathname_valid?(psz_path) -> bool

Check that psz_path is a valid ISO-9660 pathname.  

A valid pathname contains a valid directory name, if one appears and
the filename portion should be no more than 8 characters for the
file prefix and 3 characters in the extension (or portion after a
dot). There should be exactly one dot somewhere in the filename
portion and the filename should be composed of only DCHARs.
  
True is returned if psz_path is valid..
*/
SWIGINTERN VALUE
_wrap_pathname_validq___(int argc, VALUE *argv, VALUE self) {
  char *arg1 ;
  bool result;
  int res1 ;
  char *buf1 = 0 ;
  int alloc1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_AsCharPtrAndSize(argv[0], &buf1, NULL, &alloc1);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "char const []","iso9660_pathname_valid_p", 1, argv[0] ));
  }
  arg1 = (char *)(buf1);
  result = (bool)iso9660_pathname_valid_p((char const (*))arg1);
  vresult = (result != 0) ? Qtrue : Qfalse;
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return vresult;
fail:
  if (alloc1 == SWIG_NEWOBJ) free((char*)buf1);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.fs_stat

  call-seq:
    fs_stat(p_cdio, psz_path) -> IsoStat_t

Return file status for psz_path. None is returned on error..
*/
SWIGINTERN VALUE
_wrap_fs_stat(int argc, VALUE *argv, VALUE self) {
  CdIo_t *arg1 = (CdIo_t *) 0 ;
  char *arg2 ;
  IsoStat_t *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 2) || (argc > 2)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 2)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_CdIo_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "CdIo_t *","iso9660_fs_stat", 1, argv[0] )); 
  }
  arg1 = (CdIo_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(argv[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), Ruby_Format_TypeError( "", "char const []","iso9660_fs_stat", 2, argv[1] ));
  }
  arg2 = (char *)(buf2);
  result = (IsoStat_t *)iso9660_fs_stat(arg1,(char const (*))arg2);
  {
    iso9660_stat_t *p_statbuf = result;
    
    if (result) {
      VALUE resultobj = rb_hash_new();
      rb_hash_aset(resultobj, rb_str_new2("filename"), 
        rb_str_new2(p_statbuf->filename));
      rb_hash_aset(resultobj, rb_str_new2("lsn"), 
        INT2NUM(p_statbuf->lsn));
      rb_hash_aset(resultobj, rb_str_new2("size"), 
        INT2NUM(p_statbuf->size));
      rb_hash_aset(resultobj, rb_str_new2("secsize"), 
        INT2NUM(p_statbuf->secsize));
      rb_hash_aset(resultobj, rb_str_new2("type"), 
        INT2NUM(p_statbuf->type));
      free (p_statbuf);
      return resultobj;
    }
  }
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return vresult;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.fs_stat_translate

  call-seq:
    fs_stat_translate(p_cdio, psz_path, b_mode2=false) -> IsoStat_t

Return file status for path name psz_path. None is returned on error.
pathname version numbers in the ISO 9660 name are dropped, i.e. ;1
is removed and if level 1 ISO-9660 names are lowercased.

The b_mode2 parameter is not used..
*/
SWIGINTERN VALUE
_wrap_fs_stat_translate(int argc, VALUE *argv, VALUE self) {
  CdIo_t *arg1 = (CdIo_t *) 0 ;
  char *arg2 ;
  bool arg3 = (bool) false ;
  IsoStat_t *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  bool val3 ;
  int ecode3 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 2) || (argc > 3)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 2)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_CdIo_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "CdIo_t *","iso9660_fs_stat_translate", 1, argv[0] )); 
  }
  arg1 = (CdIo_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(argv[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), Ruby_Format_TypeError( "", "char const []","iso9660_fs_stat_translate", 2, argv[1] ));
  }
  arg2 = (char *)(buf2);
  if (argc > 2) {
    ecode3 = SWIG_AsVal_bool(argv[2], &val3);
    if (!SWIG_IsOK(ecode3)) {
      SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "bool","iso9660_fs_stat_translate", 3, argv[2] ));
    } 
    arg3 = (bool)(val3);
  }
  result = (IsoStat_t *)iso9660_fs_stat_translate(arg1,(char const (*))arg2,arg3);
  {
    iso9660_stat_t *p_statbuf = result;
    
    if (result) {
      VALUE resultobj = rb_hash_new();
      rb_hash_aset(resultobj, rb_str_new2("filename"), 
        rb_str_new2(p_statbuf->filename));
      rb_hash_aset(resultobj, rb_str_new2("lsn"), 
        INT2NUM(p_statbuf->lsn));
      rb_hash_aset(resultobj, rb_str_new2("size"), 
        INT2NUM(p_statbuf->size));
      rb_hash_aset(resultobj, rb_str_new2("secsize"), 
        INT2NUM(p_statbuf->secsize));
      rb_hash_aset(resultobj, rb_str_new2("type"), 
        INT2NUM(p_statbuf->type));
      free (p_statbuf);
      return resultobj;
    }
  }
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return vresult;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.ifs_stat

  call-seq:
    ifs_stat(p_iso, psz_path) -> IsoStat_t

Return file status for pathname. None is returned on error..
*/
SWIGINTERN VALUE
_wrap_ifs_stat(int argc, VALUE *argv, VALUE self) {
  iso9660_t *arg1 = (iso9660_t *) 0 ;
  char *arg2 ;
  IsoStat_t *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 2) || (argc > 2)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 2)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_t *","iso9660_ifs_stat", 1, argv[0] )); 
  }
  arg1 = (iso9660_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(argv[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), Ruby_Format_TypeError( "", "char const []","iso9660_ifs_stat", 2, argv[1] ));
  }
  arg2 = (char *)(buf2);
  result = (IsoStat_t *)iso9660_ifs_stat(arg1,(char const (*))arg2);
  {
    iso9660_stat_t *p_statbuf = result;
    
    if (result) {
      VALUE resultobj = rb_hash_new();
      rb_hash_aset(resultobj, rb_str_new2("filename"), 
        rb_str_new2(p_statbuf->filename));
      rb_hash_aset(resultobj, rb_str_new2("lsn"), 
        INT2NUM(p_statbuf->lsn));
      rb_hash_aset(resultobj, rb_str_new2("size"), 
        INT2NUM(p_statbuf->size));
      rb_hash_aset(resultobj, rb_str_new2("secsize"), 
        INT2NUM(p_statbuf->secsize));
      rb_hash_aset(resultobj, rb_str_new2("type"), 
        INT2NUM(p_statbuf->type));
      free (p_statbuf);
      return resultobj;
    }
  }
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return vresult;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.ifs_stat_translate

  call-seq:
    ifs_stat_translate(p_iso, psz_path) -> IsoStat_t

Return file status for path name psz_path. undef is returned on error.
pathname version numbers in the ISO 9660 name are dropped, i.e. ;1 is
removed and if level 1 ISO-9660 names are lowercased..
*/
SWIGINTERN VALUE
_wrap_ifs_stat_translate(int argc, VALUE *argv, VALUE self) {
  iso9660_t *arg1 = (iso9660_t *) 0 ;
  char *arg2 ;
  IsoStat_t *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 2) || (argc > 2)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 2)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_t *","iso9660_ifs_stat_translate", 1, argv[0] )); 
  }
  arg1 = (iso9660_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(argv[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), Ruby_Format_TypeError( "", "char const []","iso9660_ifs_stat_translate", 2, argv[1] ));
  }
  arg2 = (char *)(buf2);
  result = (IsoStat_t *)iso9660_ifs_stat_translate(arg1,(char const (*))arg2);
  {
    iso9660_stat_t *p_statbuf = result;
    
    if (result) {
      VALUE resultobj = rb_hash_new();
      rb_hash_aset(resultobj, rb_str_new2("filename"), 
        rb_str_new2(p_statbuf->filename));
      rb_hash_aset(resultobj, rb_str_new2("lsn"), 
        INT2NUM(p_statbuf->lsn));
      rb_hash_aset(resultobj, rb_str_new2("size"), 
        INT2NUM(p_statbuf->size));
      rb_hash_aset(resultobj, rb_str_new2("secsize"), 
        INT2NUM(p_statbuf->secsize));
      rb_hash_aset(resultobj, rb_str_new2("type"), 
        INT2NUM(p_statbuf->type));
      free (p_statbuf);
      return resultobj;
    }
  }
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return vresult;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.fs_readdir

  call-seq:
    fs_readdir(p_cdio, psz_path) -> IsoStatList_t

Read psz_path (a directory) and return a list of iso9660_stat_t
pointers for the files inside that directory..
*/
SWIGINTERN VALUE
_wrap_fs_readdir(int argc, VALUE *argv, VALUE self) {
  CdIo_t *arg1 = (CdIo_t *) 0 ;
  char *arg2 ;
  IsoStatList_t *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 2) || (argc > 2)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 2)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_CdIo_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "CdIo_t *","fs_readdir", 1, argv[0] )); 
  }
  arg1 = (CdIo_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(argv[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), Ruby_Format_TypeError( "", "char const []","fs_readdir", 2, argv[1] ));
  }
  arg2 = (char *)(buf2);
  result = (IsoStatList_t *)fs_readdir(arg1,(char const (*))arg2);
  {
    CdioList_t *p_entlist   = result;
    CdioListNode_t *p_entnode;
    
    if (result) {
      VALUE resultobj = rb_ary_new();
      _CDIO_LIST_FOREACH (p_entnode, p_entlist) {
        VALUE stat = rb_hash_new();
        iso9660_stat_t *p_statbuf = 
        (iso9660_stat_t *) _cdio_list_node_data (p_entnode);
        
        rb_hash_aset(stat, rb_str_new2("filename"), 
          rb_str_new2(p_statbuf->filename));
        rb_hash_aset(stat, rb_str_new2("lsn"), 
          INT2NUM(p_statbuf->lsn));
        rb_hash_aset(stat, rb_str_new2("size"), 
          INT2NUM(p_statbuf->size));
        rb_hash_aset(stat, rb_str_new2("secsize"), 
          INT2NUM(p_statbuf->secsize));
        rb_hash_aset(stat, rb_str_new2("type"), 
          INT2NUM(p_statbuf->type));
        rb_ary_push(resultobj, stat);
        
      }
      _cdio_list_free(result, 1);
      return resultobj;
    }
  }
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return vresult;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.ifs_readdir

  call-seq:
    ifs_readdir(p_iso, psz_path) -> IsoStatList_t

Read psz_path (a directory) and return a list of iso9660_stat_t
pointers for the files inside that directory..
*/
SWIGINTERN VALUE
_wrap_ifs_readdir(int argc, VALUE *argv, VALUE self) {
  iso9660_t *arg1 = (iso9660_t *) 0 ;
  char *arg2 ;
  IsoStatList_t *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 2) || (argc > 2)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 2)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_t *","ifs_readdir", 1, argv[0] )); 
  }
  arg1 = (iso9660_t *)(argp1);
  res2 = SWIG_AsCharPtrAndSize(argv[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), Ruby_Format_TypeError( "", "char const []","ifs_readdir", 2, argv[1] ));
  }
  arg2 = (char *)(buf2);
  result = (IsoStatList_t *)ifs_readdir(arg1,(char const (*))arg2);
  {
    CdioList_t *p_entlist   = result;
    CdioListNode_t *p_entnode;
    
    if (result) {
      VALUE resultobj = rb_ary_new();
      _CDIO_LIST_FOREACH (p_entnode, p_entlist) {
        VALUE stat = rb_hash_new();
        iso9660_stat_t *p_statbuf = 
        (iso9660_stat_t *) _cdio_list_node_data (p_entnode);
        
        rb_hash_aset(stat, rb_str_new2("filename"), 
          rb_str_new2(p_statbuf->filename));
        rb_hash_aset(stat, rb_str_new2("lsn"), 
          INT2NUM(p_statbuf->lsn));
        rb_hash_aset(stat, rb_str_new2("size"), 
          INT2NUM(p_statbuf->size));
        rb_hash_aset(stat, rb_str_new2("secsize"), 
          INT2NUM(p_statbuf->secsize));
        rb_hash_aset(stat, rb_str_new2("type"), 
          INT2NUM(p_statbuf->type));
        rb_ary_push(resultobj, stat);
        
      }
      _cdio_list_free(result, 1);
      return resultobj;
    }
  }
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return vresult;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.get_application_id

  call-seq:
    get_application_id(p_pvd) -> char

Return the PVD's application ID.
None is returned if there is some problem in getting this..
*/
SWIGINTERN VALUE
_wrap_get_application_id(int argc, VALUE *argv, VALUE self) {
  iso9660_pvd_t *arg1 = (iso9660_pvd_t *) 0 ;
  char *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_pvd_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_pvd_t *","iso9660_get_application_id", 1, argv[0] )); 
  }
  arg1 = (iso9660_pvd_t *)(argp1);
  result = (char *)iso9660_get_application_id(arg1);
  vresult = SWIG_FromCharPtr((const char *)result);
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.ifs_get_application_id

  call-seq:
    ifs_get_application_id(p_iso) -> string_or_nil_t

Get the application ID.  Return None if there
is some problem in getting this..
*/
SWIGINTERN VALUE
_wrap_ifs_get_application_id(int argc, VALUE *argv, VALUE self) {
  iso9660_t *arg1 = (iso9660_t *) 0 ;
  string_or_nil_t result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_t *","ifs_get_application_id", 1, argv[0] )); 
  }
  arg1 = (iso9660_t *)(argp1);
  result = (string_or_nil_t)ifs_get_application_id(arg1);
  {
    if (result == NULL) return Qnil;
    vresult = rb_str_new2(result);
  }
  free((char*)result);
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.get_joliet_level

  call-seq:
    get_joliet_level(p_iso) -> unsigned char

Return the Joliet level recognized for p_iso..
*/
SWIGINTERN VALUE
_wrap_get_joliet_level(int argc, VALUE *argv, VALUE self) {
  iso9660_t *arg1 = (iso9660_t *) 0 ;
  unsigned char result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_t *","iso9660_ifs_get_joliet_level", 1, argv[0] )); 
  }
  arg1 = (iso9660_t *)(argp1);
  result = (unsigned char)iso9660_ifs_get_joliet_level(arg1);
  vresult = SWIG_From_unsigned_SS_char((unsigned char)(result));
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.get_dir_len

  call-seq:
    get_dir_len(p_idr) -> unsigned char

Return the Joliet level recognized for p_iso..
*/
SWIGINTERN VALUE
_wrap_get_dir_len(int argc, VALUE *argv, VALUE self) {
  iso9660_dir_t *arg1 = (iso9660_dir_t *) 0 ;
  unsigned char result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_dir_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_dir_t const *","iso9660_get_dir_len", 1, argv[0] )); 
  }
  arg1 = (iso9660_dir_t *)(argp1);
  result = (unsigned char)iso9660_get_dir_len((iso9660_dir_t const *)arg1);
  vresult = SWIG_From_unsigned_SS_char((unsigned char)(result));
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.iso9660_dir_to_name

  call-seq:
    iso9660_dir_to_name(p_iso9660_dir) -> char

Return the directory name stored in the iso9660_dir_t..
*/
SWIGINTERN VALUE
_wrap_iso9660_dir_to_name(int argc, VALUE *argv, VALUE self) {
  iso9660_dir_t *arg1 = (iso9660_dir_t *) 0 ;
  char *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_dir_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_dir_t const *","iso9660_dir_to_name", 1, argv[0] )); 
  }
  arg1 = (iso9660_dir_t *)(argp1);
  result = (char *)iso9660_dir_to_name((iso9660_dir_t const *)arg1);
  vresult = SWIG_FromCharPtr((const char *)result);
  free((char*)result);
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.get_preparer_id

  call-seq:
    get_preparer_id(p_pvd) -> char

Return a string containing the preparer id with trailing
blanks removed..
*/
SWIGINTERN VALUE
_wrap_get_preparer_id(int argc, VALUE *argv, VALUE self) {
  iso9660_pvd_t *arg1 = (iso9660_pvd_t *) 0 ;
  char *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_pvd_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_pvd_t const *","iso9660_get_preparer_id", 1, argv[0] )); 
  }
  arg1 = (iso9660_pvd_t *)(argp1);
  result = (char *)iso9660_get_preparer_id((iso9660_pvd_t const *)arg1);
  vresult = SWIG_FromCharPtr((const char *)result);
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.ifs_get_preparer_id

  call-seq:
    ifs_get_preparer_id(p_iso) -> string_or_nil_t

Get the preparer ID.  Return None if there is some problem in
 getting this..
*/
SWIGINTERN VALUE
_wrap_ifs_get_preparer_id(int argc, VALUE *argv, VALUE self) {
  iso9660_t *arg1 = (iso9660_t *) 0 ;
  string_or_nil_t result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_t *","ifs_get_preparer_id", 1, argv[0] )); 
  }
  arg1 = (iso9660_t *)(argp1);
  result = (string_or_nil_t)ifs_get_preparer_id(arg1);
  {
    if (result == NULL) return Qnil;
    vresult = rb_str_new2(result);
  }
  free((char*)result);
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.get_publisher_id

  call-seq:
    get_publisher_id(p_pvd) -> char

Return a string containing the PVD's publisher id with trailing
 blanks removed..
*/
SWIGINTERN VALUE
_wrap_get_publisher_id(int argc, VALUE *argv, VALUE self) {
  iso9660_pvd_t *arg1 = (iso9660_pvd_t *) 0 ;
  char *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_pvd_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_pvd_t const *","iso9660_get_publisher_id", 1, argv[0] )); 
  }
  arg1 = (iso9660_pvd_t *)(argp1);
  result = (char *)iso9660_get_publisher_id((iso9660_pvd_t const *)arg1);
  vresult = SWIG_FromCharPtr((const char *)result);
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.ifs_get_publisher_id

  call-seq:
    ifs_get_publisher_id(p_iso) -> string_or_nil_t

Get the publisher ID. Return None if there
is some problem in getting this..
*/
SWIGINTERN VALUE
_wrap_ifs_get_publisher_id(int argc, VALUE *argv, VALUE self) {
  iso9660_t *arg1 = (iso9660_t *) 0 ;
  string_or_nil_t result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_t *","ifs_get_publisher_id", 1, argv[0] )); 
  }
  arg1 = (iso9660_t *)(argp1);
  result = (string_or_nil_t)ifs_get_publisher_id(arg1);
  {
    if (result == NULL) return Qnil;
    vresult = rb_str_new2(result);
  }
  free((char*)result);
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.get_pvd_type

  call-seq:
    get_pvd_type(p_pvd) -> unsigned char

Get the publisher ID. Return None if there
is some problem in getting this..
*/
SWIGINTERN VALUE
_wrap_get_pvd_type(int argc, VALUE *argv, VALUE self) {
  iso9660_pvd_t *arg1 = (iso9660_pvd_t *) 0 ;
  unsigned char result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_pvd_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_pvd_t const *","iso9660_get_pvd_type", 1, argv[0] )); 
  }
  arg1 = (iso9660_pvd_t *)(argp1);
  result = (unsigned char)iso9660_get_pvd_type((iso9660_pvd_t const *)arg1);
  vresult = SWIG_From_unsigned_SS_char((unsigned char)(result));
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.get_pvd_id

  call-seq:
    get_pvd_id(p_pvd) -> char

Get the publisher ID. Return None if there
is some problem in getting this..
*/
SWIGINTERN VALUE
_wrap_get_pvd_id(int argc, VALUE *argv, VALUE self) {
  iso9660_pvd_t *arg1 = (iso9660_pvd_t *) 0 ;
  char *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_pvd_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_pvd_t const *","iso9660_get_pvd_id", 1, argv[0] )); 
  }
  arg1 = (iso9660_pvd_t *)(argp1);
  result = (char *)iso9660_get_pvd_id((iso9660_pvd_t const *)arg1);
  vresult = SWIG_FromCharPtr((const char *)result);
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.get_pvd_space_size

  call-seq:
    get_pvd_space_size(p_pvd) -> int

Get the publisher ID. Return None if there
is some problem in getting this..
*/
SWIGINTERN VALUE
_wrap_get_pvd_space_size(int argc, VALUE *argv, VALUE self) {
  iso9660_pvd_t *arg1 = (iso9660_pvd_t *) 0 ;
  int result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_pvd_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_pvd_t const *","iso9660_get_pvd_space_size", 1, argv[0] )); 
  }
  arg1 = (iso9660_pvd_t *)(argp1);
  result = (int)iso9660_get_pvd_space_size((iso9660_pvd_t const *)arg1);
  vresult = SWIG_From_int((int)(result));
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.get_pvd_block_size

  call-seq:
    get_pvd_block_size(p_pvd) -> int

Get the publisher ID. Return None if there
is some problem in getting this..
*/
SWIGINTERN VALUE
_wrap_get_pvd_block_size(int argc, VALUE *argv, VALUE self) {
  iso9660_pvd_t *arg1 = (iso9660_pvd_t *) 0 ;
  int result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_pvd_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_pvd_t const *","iso9660_get_pvd_block_size", 1, argv[0] )); 
  }
  arg1 = (iso9660_pvd_t *)(argp1);
  result = (int)iso9660_get_pvd_block_size((iso9660_pvd_t const *)arg1);
  vresult = SWIG_From_int((int)(result));
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.get_pvd_version

  call-seq:
    get_pvd_version(pvd) -> int

Return the primary volume id version number (of pvd).
If there is an error 0 is returned..
*/
SWIGINTERN VALUE
_wrap_get_pvd_version(int argc, VALUE *argv, VALUE self) {
  iso9660_pvd_t *arg1 = (iso9660_pvd_t *) 0 ;
  int result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_pvd_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_pvd_t const *","iso9660_get_pvd_version", 1, argv[0] )); 
  }
  arg1 = (iso9660_pvd_t *)(argp1);
  result = (int)iso9660_get_pvd_version((iso9660_pvd_t const *)arg1);
  vresult = SWIG_From_int((int)(result));
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.get_system_id

  call-seq:
    get_system_id(p_pvd) -> char

Return a string containing the PVD's system id with trailing
 blanks removed..
*/
SWIGINTERN VALUE
_wrap_get_system_id(int argc, VALUE *argv, VALUE self) {
  iso9660_pvd_t *arg1 = (iso9660_pvd_t *) 0 ;
  char *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_pvd_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_pvd_t const *","iso9660_get_system_id", 1, argv[0] )); 
  }
  arg1 = (iso9660_pvd_t *)(argp1);
  result = (char *)iso9660_get_system_id((iso9660_pvd_t const *)arg1);
  vresult = SWIG_FromCharPtr((const char *)result);
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.ifs_get_system_id

  call-seq:
    ifs_get_system_id(p_iso) -> char

Get the system ID.  None is returned if there
is some problem in getting this..
*/
SWIGINTERN VALUE
_wrap_ifs_get_system_id(int argc, VALUE *argv, VALUE self) {
  iso9660_t *arg1 = (iso9660_t *) 0 ;
  char *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_t *","ifs_get_system_id", 1, argv[0] )); 
  }
  arg1 = (iso9660_t *)(argp1);
  result = (char *)ifs_get_system_id(arg1);
  vresult = SWIG_FromCharPtr((const char *)result);
  free((char*)result);
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.get_root_lsn

  call-seq:
    get_root_lsn(p_pvd) -> lsn_t

Return the LSN of the root directory for pvd.  If there is an error
INVALID_LSN is returned.
.
*/
SWIGINTERN VALUE
_wrap_get_root_lsn(int argc, VALUE *argv, VALUE self) {
  iso9660_pvd_t *arg1 = (iso9660_pvd_t *) 0 ;
  lsn_t result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_pvd_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_pvd_t const *","iso9660_get_root_lsn", 1, argv[0] )); 
  }
  arg1 = (iso9660_pvd_t *)(argp1);
  result = (lsn_t)iso9660_get_root_lsn((iso9660_pvd_t const *)arg1);
  vresult = SWIG_From_int((int)(result));
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.get_volume_id

  call-seq:
    get_volume_id(p_pvd) -> char

Return the PVD's volume ID..
*/
SWIGINTERN VALUE
_wrap_get_volume_id(int argc, VALUE *argv, VALUE self) {
  iso9660_pvd_t *arg1 = (iso9660_pvd_t *) 0 ;
  char *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_pvd_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_pvd_t const *","iso9660_get_volume_id", 1, argv[0] )); 
  }
  arg1 = (iso9660_pvd_t *)(argp1);
  result = (char *)iso9660_get_volume_id((iso9660_pvd_t const *)arg1);
  vresult = SWIG_FromCharPtr((const char *)result);
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.ifs_get_volume_id

  call-seq:
    ifs_get_volume_id(p_iso) -> char

Get the system ID. None is returned if there
is some problem in getting this..
*/
SWIGINTERN VALUE
_wrap_ifs_get_volume_id(int argc, VALUE *argv, VALUE self) {
  iso9660_t *arg1 = (iso9660_t *) 0 ;
  char *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_t *","ifs_get_volume_id", 1, argv[0] )); 
  }
  arg1 = (iso9660_t *)(argp1);
  result = (char *)ifs_get_volume_id(arg1);
  vresult = SWIG_FromCharPtr((const char *)result);
  free((char*)result);
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.get_volumeset_id

  call-seq:
    get_volumeset_id(p_pvd) -> char

  Return the PVD's volumeset ID.
  None is returned if there is some problem in getting this. 
.
*/
SWIGINTERN VALUE
_wrap_get_volumeset_id(int argc, VALUE *argv, VALUE self) {
  iso9660_pvd_t *arg1 = (iso9660_pvd_t *) 0 ;
  char *result = 0 ;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_pvd_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_pvd_t const *","iso9660_get_volumeset_id", 1, argv[0] )); 
  }
  arg1 = (iso9660_pvd_t *)(argp1);
  result = (char *)iso9660_get_volumeset_id((iso9660_pvd_t const *)arg1);
  vresult = SWIG_FromCharPtr((const char *)result);
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.ifs_get_volumeset_id

  call-seq:
    ifs_get_volumeset_id(p_iso) -> string_or_nil_t

Get the volumeset ID.  None is returned if there
is some problem in getting this..
*/
SWIGINTERN VALUE
_wrap_ifs_get_volumeset_id(int argc, VALUE *argv, VALUE self) {
  iso9660_t *arg1 = (iso9660_t *) 0 ;
  string_or_nil_t result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_t *","ifs_get_volumeset_id", 1, argv[0] )); 
  }
  arg1 = (iso9660_t *)(argp1);
  result = (string_or_nil_t)ifs_get_volumeset_id(arg1);
  {
    if (result == NULL) return Qnil;
    vresult = rb_str_new2(result);
  }
  free((char*)result);
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.pathtable_init

  call-seq:
    pathtable_init(pt)

Zero's out pathable. Do this first..
*/
SWIGINTERN VALUE
_wrap_pathtable_init(int argc, VALUE *argv, VALUE self) {
  void *arg1 = (void *) 0 ;
  int res1 ;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0],SWIG_as_voidptrptr(&arg1), 0, 0);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "void *","iso9660_pathtable_init", 1, argv[0] )); 
  }
  iso9660_pathtable_init(arg1);
  return Qnil;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.pathtable_get_size

  call-seq:
    pathtable_get_size(pt) -> unsigned int

Zero's out pathable. Do this first..
*/
SWIGINTERN VALUE
_wrap_pathtable_get_size(int argc, VALUE *argv, VALUE self) {
  void *arg1 = (void *) 0 ;
  unsigned int result;
  int res1 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0],SWIG_as_voidptrptr(&arg1), 0, 0);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "void const *","iso9660_pathtable_get_size", 1, argv[0] )); 
  }
  result = (unsigned int)iso9660_pathtable_get_size((void const *)arg1);
  vresult = SWIG_From_unsigned_SS_int((unsigned int)(result));
  return vresult;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.pathtable_l_add_entry

  call-seq:
    pathtable_l_add_entry(pt, name, extent, parent) -> unsigned int

Zero's out pathable. Do this first..
*/
SWIGINTERN VALUE
_wrap_pathtable_l_add_entry(int argc, VALUE *argv, VALUE self) {
  void *arg1 = (void *) 0 ;
  char *arg2 ;
  unsigned int arg3 ;
  unsigned int arg4 ;
  unsigned int result;
  int res1 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  unsigned int val3 ;
  int ecode3 = 0 ;
  unsigned int val4 ;
  int ecode4 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 4) || (argc > 4)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 4)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0],SWIG_as_voidptrptr(&arg1), 0, 0);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "void *","iso9660_pathtable_l_add_entry", 1, argv[0] )); 
  }
  res2 = SWIG_AsCharPtrAndSize(argv[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), Ruby_Format_TypeError( "", "char const []","iso9660_pathtable_l_add_entry", 2, argv[1] ));
  }
  arg2 = (char *)(buf2);
  ecode3 = SWIG_AsVal_unsigned_SS_int(argv[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "unsigned int","iso9660_pathtable_l_add_entry", 3, argv[2] ));
  } 
  arg3 = (unsigned int)(val3);
  ecode4 = SWIG_AsVal_unsigned_SS_int(argv[3], &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), Ruby_Format_TypeError( "", "unsigned int","iso9660_pathtable_l_add_entry", 4, argv[3] ));
  } 
  arg4 = (unsigned int)(val4);
  result = (unsigned int)iso9660_pathtable_l_add_entry(arg1,(char const (*))arg2,arg3,arg4);
  vresult = SWIG_From_unsigned_SS_int((unsigned int)(result));
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return vresult;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.pathtable_m_add_entry

  call-seq:
    pathtable_m_add_entry(pt, name, extent, parent) -> unsigned int

Zero's out pathable. Do this first..
*/
SWIGINTERN VALUE
_wrap_pathtable_m_add_entry(int argc, VALUE *argv, VALUE self) {
  void *arg1 = (void *) 0 ;
  char *arg2 ;
  unsigned int arg3 ;
  unsigned int arg4 ;
  unsigned int result;
  int res1 ;
  int res2 ;
  char *buf2 = 0 ;
  int alloc2 = 0 ;
  unsigned int val3 ;
  int ecode3 = 0 ;
  unsigned int val4 ;
  int ecode4 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 4) || (argc > 4)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 4)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0],SWIG_as_voidptrptr(&arg1), 0, 0);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "void *","iso9660_pathtable_m_add_entry", 1, argv[0] )); 
  }
  res2 = SWIG_AsCharPtrAndSize(argv[1], &buf2, NULL, &alloc2);
  if (!SWIG_IsOK(res2)) {
    SWIG_exception_fail(SWIG_ArgError(res2), Ruby_Format_TypeError( "", "char const []","iso9660_pathtable_m_add_entry", 2, argv[1] ));
  }
  arg2 = (char *)(buf2);
  ecode3 = SWIG_AsVal_unsigned_SS_int(argv[2], &val3);
  if (!SWIG_IsOK(ecode3)) {
    SWIG_exception_fail(SWIG_ArgError(ecode3), Ruby_Format_TypeError( "", "unsigned int","iso9660_pathtable_m_add_entry", 3, argv[2] ));
  } 
  arg3 = (unsigned int)(val3);
  ecode4 = SWIG_AsVal_unsigned_SS_int(argv[3], &val4);
  if (!SWIG_IsOK(ecode4)) {
    SWIG_exception_fail(SWIG_ArgError(ecode4), Ruby_Format_TypeError( "", "unsigned int","iso9660_pathtable_m_add_entry", 4, argv[3] ));
  } 
  arg4 = (unsigned int)(val4);
  result = (unsigned int)iso9660_pathtable_m_add_entry(arg1,(char const (*))arg2,arg3,arg4);
  vresult = SWIG_From_unsigned_SS_int((unsigned int)(result));
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return vresult;
fail:
  if (alloc2 == SWIG_NEWOBJ) free((char*)buf2);
  return Qnil;
}



/*
  Document-method: Rubyiso9660.set_evd

  call-seq:
    set_evd(pd)

Zero's out pathable. Do this first..
*/
SWIGINTERN VALUE
_wrap_set_evd(int argc, VALUE *argv, VALUE self) {
  void *arg1 = (void *) 0 ;
  int res1 ;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0],SWIG_as_voidptrptr(&arg1), 0, 0);
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "void *","iso9660_set_evd", 1, argv[0] )); 
  }
  iso9660_set_evd(arg1);
  return Qnil;
fail:
  return Qnil;
}



/*
  Document-method: Rubyiso9660.xa?

  call-seq:
    xa?(p_iso) -> bool

Return true if ISO 9660 image has extended attrributes (XA)..
*/
SWIGINTERN VALUE
_wrap_xaq___(int argc, VALUE *argv, VALUE self) {
  iso9660_t *arg1 = (iso9660_t *) 0 ;
  bool result;
  void *argp1 = 0 ;
  int res1 = 0 ;
  VALUE vresult = Qnil;
  
  if ((argc < 1) || (argc > 1)) {
    rb_raise(rb_eArgError, "wrong # of arguments(%d for 1)",argc); SWIG_fail;
  }
  res1 = SWIG_ConvertPtr(argv[0], &argp1,SWIGTYPE_p_iso9660_t, 0 |  0 );
  if (!SWIG_IsOK(res1)) {
    SWIG_exception_fail(SWIG_ArgError(res1), Ruby_Format_TypeError( "", "iso9660_t const *","iso9660_ifs_is_xa", 1, argv[0] )); 
  }
  arg1 = (iso9660_t *)(argp1);
  result = (bool)iso9660_ifs_is_xa((iso9660_t const *)arg1);
  vresult = (result != 0) ? Qtrue : Qfalse;
  return vresult;
fail:
  return Qnil;
}



/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (BEGIN) -------- */

static swig_type_info _swigt__p_Buf_tuple_t = {"_p_Buf_tuple_t", "Buf_tuple_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_CdIo_t = {"_p_CdIo_t", "CdIo_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_CdioList_t = {"_p_CdioList_t", "CdioList_t *|IsoStatList_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_cdio_read_mode_t = {"_p_cdio_read_mode_t", "enum cdio_read_mode_t *|cdio_read_mode_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_char = {"_p_char", "char *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_int = {"_p_int", "int *|lba_t *|lsn_t *|int16_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_iso9660_dir_t = {"_p_iso9660_dir_t", "iso9660_dir_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_iso9660_dtime_t = {"_p_iso9660_dtime_t", "iso9660_dtime_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_iso9660_ltime_t = {"_p_iso9660_ltime_t", "iso9660_ltime_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_iso9660_pvd_t = {"_p_iso9660_pvd_t", "iso9660_pvd_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_iso9660_stat_t = {"_p_iso9660_stat_t", "iso9660_stat_t *|IsoStat_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_iso9660_t = {"_p_iso9660_t", "iso9660_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_long = {"_p_long", "my_ssize_t *|ssize_t *|long *|driver_return_code_t *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_unsigned_int = {"_p_unsigned_int", "track_t *|unsigned int *|cdio_drive_write_cap_t *|cdio_drive_misc_cap_t *|cdio_drive_read_cap_t *|iso_extension_mask_t *|driver_id_t *", 0, 0, (void*)0, 0};

static swig_type_info *swig_type_initial[] = {
  &_swigt__p_Buf_tuple_t,
  &_swigt__p_CdIo_t,
  &_swigt__p_CdioList_t,
  &_swigt__p_cdio_read_mode_t,
  &_swigt__p_char,
  &_swigt__p_int,
  &_swigt__p_iso9660_dir_t,
  &_swigt__p_iso9660_dtime_t,
  &_swigt__p_iso9660_ltime_t,
  &_swigt__p_iso9660_pvd_t,
  &_swigt__p_iso9660_stat_t,
  &_swigt__p_iso9660_t,
  &_swigt__p_long,
  &_swigt__p_unsigned_int,
};

static swig_cast_info _swigc__p_Buf_tuple_t[] = {  {&_swigt__p_Buf_tuple_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_CdIo_t[] = {  {&_swigt__p_CdIo_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_CdioList_t[] = {  {&_swigt__p_CdioList_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_cdio_read_mode_t[] = {  {&_swigt__p_cdio_read_mode_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_char[] = {  {&_swigt__p_char, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_int[] = {  {&_swigt__p_int, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_iso9660_dir_t[] = {  {&_swigt__p_iso9660_dir_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_iso9660_dtime_t[] = {  {&_swigt__p_iso9660_dtime_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_iso9660_ltime_t[] = {  {&_swigt__p_iso9660_ltime_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_iso9660_pvd_t[] = {  {&_swigt__p_iso9660_pvd_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_iso9660_stat_t[] = {  {&_swigt__p_iso9660_stat_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_iso9660_t[] = {  {&_swigt__p_iso9660_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_long[] = {  {&_swigt__p_long, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_unsigned_int[] = {  {&_swigt__p_unsigned_int, 0, 0, 0},{0, 0, 0, 0}};

static swig_cast_info *swig_cast_initial[] = {
  _swigc__p_Buf_tuple_t,
  _swigc__p_CdIo_t,
  _swigc__p_CdioList_t,
  _swigc__p_cdio_read_mode_t,
  _swigc__p_char,
  _swigc__p_int,
  _swigc__p_iso9660_dir_t,
  _swigc__p_iso9660_dtime_t,
  _swigc__p_iso9660_ltime_t,
  _swigc__p_iso9660_pvd_t,
  _swigc__p_iso9660_stat_t,
  _swigc__p_iso9660_t,
  _swigc__p_long,
  _swigc__p_unsigned_int,
};


/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (END) -------- */

/* -----------------------------------------------------------------------------
 * Type initialization:
 * This problem is tough by the requirement that no dynamic 
 * memory is used. Also, since swig_type_info structures store pointers to 
 * swig_cast_info structures and swig_cast_info structures store pointers back
 * to swig_type_info structures, we need some lookup code at initialization. 
 * The idea is that swig generates all the structures that are needed. 
 * The runtime then collects these partially filled structures. 
 * The SWIG_InitializeModule function takes these initial arrays out of 
 * swig_module, and does all the lookup, filling in the swig_module.types
 * array with the correct data and linking the correct swig_cast_info
 * structures together.
 *
 * The generated swig_type_info structures are assigned staticly to an initial 
 * array. We just loop through that array, and handle each type individually.
 * First we lookup if this type has been already loaded, and if so, use the
 * loaded structure instead of the generated one. Then we have to fill in the
 * cast linked list. The cast data is initially stored in something like a
 * two-dimensional array. Each row corresponds to a type (there are the same
 * number of rows as there are in the swig_type_initial array). Each entry in
 * a column is one of the swig_cast_info structures for that type.
 * The cast_initial array is actually an array of arrays, because each row has
 * a variable number of columns. So to actually build the cast linked list,
 * we find the array of casts associated with the type, and loop through it 
 * adding the casts to the list. The one last trick we need to do is making
 * sure the type pointer in the swig_cast_info struct is correct.
 *
 * First off, we lookup the cast->type name to see if it is already loaded. 
 * There are three cases to handle:
 *  1) If the cast->type has already been loaded AND the type we are adding
 *     casting info to has not been loaded (it is in this module), THEN we
 *     replace the cast->type pointer with the type pointer that has already
 *     been loaded.
 *  2) If BOTH types (the one we are adding casting info to, and the 
 *     cast->type) are loaded, THEN the cast info has already been loaded by
 *     the previous module so we just ignore it.
 *  3) Finally, if cast->type has not already been loaded, then we add that
 *     swig_cast_info to the linked list (because the cast->type) pointer will
 *     be correct.
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#if 0
} /* c-mode */
#endif
#endif

#if 0
#define SWIGRUNTIME_DEBUG
#endif


SWIGRUNTIME void
SWIG_InitializeModule(void *clientdata) {
  size_t i;
  swig_module_info *module_head, *iter;
  int found;

  clientdata = clientdata;

  /* check to see if the circular list has been setup, if not, set it up */
  if (swig_module.next==0) {
    /* Initialize the swig_module */
    swig_module.type_initial = swig_type_initial;
    swig_module.cast_initial = swig_cast_initial;
    swig_module.next = &swig_module;
  }

  /* Try and load any already created modules */
  module_head = SWIG_GetModule(clientdata);
  if (!module_head) {
    /* This is the first module loaded for this interpreter */
    /* so set the swig module into the interpreter */
    SWIG_SetModule(clientdata, &swig_module);
    module_head = &swig_module;
  } else {
    /* the interpreter has loaded a SWIG module, but has it loaded this one? */
    found=0;
    iter=module_head;
    do {
      if (iter==&swig_module) {
        found=1;
        break;
      }
      iter=iter->next;
    } while (iter!= module_head);

    /* if the is found in the list, then all is done and we may leave */
    if (found) return;
    /* otherwise we must add out module into the list */
    swig_module.next = module_head->next;
    module_head->next = &swig_module;
  }

  /* Now work on filling in swig_module.types */
#ifdef SWIGRUNTIME_DEBUG
  printf("SWIG_InitializeModule: size %d\n", swig_module.size);
#endif
  for (i = 0; i < swig_module.size; ++i) {
    swig_type_info *type = 0;
    swig_type_info *ret;
    swig_cast_info *cast;
  
#ifdef SWIGRUNTIME_DEBUG
    printf("SWIG_InitializeModule: type %d %s\n", i, swig_module.type_initial[i]->name);
#endif

    /* if there is another module already loaded */
    if (swig_module.next != &swig_module) {
      type = SWIG_MangledTypeQueryModule(swig_module.next, &swig_module, swig_module.type_initial[i]->name);
    }
    if (type) {
      /* Overwrite clientdata field */
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: found type %s\n", type->name);
#endif
      if (swig_module.type_initial[i]->clientdata) {
	type->clientdata = swig_module.type_initial[i]->clientdata;
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: found and overwrite type %s \n", type->name);
#endif
      }
    } else {
      type = swig_module.type_initial[i];
    }

    /* Insert casting types */
    cast = swig_module.cast_initial[i];
    while (cast->type) {
    
      /* Don't need to add information already in the list */
      ret = 0;
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: look cast %s\n", cast->type->name);
#endif
      if (swig_module.next != &swig_module) {
        ret = SWIG_MangledTypeQueryModule(swig_module.next, &swig_module, cast->type->name);
#ifdef SWIGRUNTIME_DEBUG
	if (ret) printf("SWIG_InitializeModule: found cast %s\n", ret->name);
#endif
      }
      if (ret) {
	if (type == swig_module.type_initial[i]) {
#ifdef SWIGRUNTIME_DEBUG
	  printf("SWIG_InitializeModule: skip old type %s\n", ret->name);
#endif
	  cast->type = ret;
	  ret = 0;
	} else {
	  /* Check for casting already in the list */
	  swig_cast_info *ocast = SWIG_TypeCheck(ret->name, type);
#ifdef SWIGRUNTIME_DEBUG
	  if (ocast) printf("SWIG_InitializeModule: skip old cast %s\n", ret->name);
#endif
	  if (!ocast) ret = 0;
	}
      }

      if (!ret) {
#ifdef SWIGRUNTIME_DEBUG
	printf("SWIG_InitializeModule: adding cast %s\n", cast->type->name);
#endif
        if (type->cast) {
          type->cast->prev = cast;
          cast->next = type->cast;
        }
        type->cast = cast;
      }
      cast++;
    }
    /* Set entry in modules->types array equal to the type */
    swig_module.types[i] = type;
  }
  swig_module.types[i] = 0;

#ifdef SWIGRUNTIME_DEBUG
  printf("**** SWIG_InitializeModule: Cast List ******\n");
  for (i = 0; i < swig_module.size; ++i) {
    int j = 0;
    swig_cast_info *cast = swig_module.cast_initial[i];
    printf("SWIG_InitializeModule: type %d %s\n", i, swig_module.type_initial[i]->name);
    while (cast->type) {
      printf("SWIG_InitializeModule: cast type %s\n", cast->type->name);
      cast++;
      ++j;
    }
  printf("---- Total casts: %d\n",j);
  }
  printf("**** SWIG_InitializeModule: Cast List ******\n");
#endif
}

/* This function will propagate the clientdata field of type to
* any new swig_type_info structures that have been added into the list
* of equivalent types.  It is like calling
* SWIG_TypeClientData(type, clientdata) a second time.
*/
SWIGRUNTIME void
SWIG_PropagateClientData(void) {
  size_t i;
  swig_cast_info *equiv;
  static int init_run = 0;

  if (init_run) return;
  init_run = 1;

  for (i = 0; i < swig_module.size; i++) {
    if (swig_module.types[i]->clientdata) {
      equiv = swig_module.types[i]->cast;
      while (equiv) {
        if (!equiv->converter) {
          if (equiv->type && !equiv->type->clientdata)
            SWIG_TypeClientData(equiv->type, swig_module.types[i]->clientdata);
        }
        equiv = equiv->next;
      }
    }
  }
}

#ifdef __cplusplus
#if 0
{ /* c-mode */
#endif
}
#endif

/*

*/
#ifdef __cplusplus
extern "C"
#endif
SWIGEXPORT void Init_rubyiso9660(void) {
  size_t i;
  
  SWIG_InitRuntime();
  mRubyiso9660 = rb_define_module("Rubyiso9660");
  
  SWIG_InitializeModule(0);
  for (i = 0; i < swig_module.size; i++) {
    SWIG_define_class(swig_module.types[i]);
  }
  
  SWIG_RubyInitializeTrackings();
  rb_define_const(mRubyiso9660, "VERSION_NUM", SWIG_From_long((long)(LIBCDIO_VERSION_NUM)));
  rb_define_const(mRubyiso9660, "INVALID_LBA", SWIG_From_long((long)(CDIO_INVALID_LBA)));
  rb_define_const(mRubyiso9660, "INVALID_LSN", SWIG_From_long((long)(CDIO_INVALID_LSN)));
  rb_define_const(mRubyiso9660, "CD_FRAMESIZE", SWIG_From_long((long)(CDIO_CD_FRAMESIZE)));
  rb_define_const(mRubyiso9660, "CD_FRAMESIZE_RAW", SWIG_From_long((long)(CDIO_CD_FRAMESIZE_RAW)));
  rb_define_const(mRubyiso9660, "ISO_BLOCKSIZE", SWIG_From_long((long)(CDIO_CD_FRAMESIZE)));
  rb_define_const(mRubyiso9660, "M2F2_SECTOR_SIZE", SWIG_From_long((long)(M2F2_SECTOR_SIZE)));
  rb_define_const(mRubyiso9660, "M2RAW_SECTOR_SIZE", SWIG_From_long((long)(M2RAW_SECTOR_SIZE)));
  rb_define_const(mRubyiso9660, "CDIO_READ_MODE_AUDIO", SWIG_From_int((int)(CDIO_READ_MODE_AUDIO)));
  rb_define_const(mRubyiso9660, "CDIO_READ_MODE_M1F1", SWIG_From_int((int)(CDIO_READ_MODE_M1F1)));
  rb_define_const(mRubyiso9660, "CDIO_READ_MODE_M1F2", SWIG_From_int((int)(CDIO_READ_MODE_M1F2)));
  rb_define_const(mRubyiso9660, "CDIO_READ_MODE_M2F1", SWIG_From_int((int)(CDIO_READ_MODE_M2F1)));
  rb_define_const(mRubyiso9660, "CDIO_READ_MODE_M2F2", SWIG_From_int((int)(CDIO_READ_MODE_M2F2)));
  rb_define_module_function(mRubyiso9660, "cdio_read_sectors", _wrap_cdio_read_sectors, -1);
  rb_define_module_function(mRubyiso9660, "cdio_eject_media_drive", _wrap_cdio_eject_media_drive, -1);
  rb_define_const(mRubyiso9660, "PVD_SECTOR", SWIG_From_long((long)(ISO_PVD_SECTOR)));
  rb_define_const(mRubyiso9660, "EVD_SECTOR", SWIG_From_long((long)(ISO_EVD_SECTOR)));
  rb_define_const(mRubyiso9660, "LEN_ISONAME", SWIG_From_long((long)(LEN_ISONAME)));
  rb_define_const(mRubyiso9660, "MAX_SYSTEM_ID", SWIG_From_long((long)(ISO_MAX_SYSTEM_ID)));
  rb_define_const(mRubyiso9660, "MAX_ISONAME", SWIG_From_long((long)(MAX_ISONAME)));
  rb_define_const(mRubyiso9660, "MAX_PREPARER_ID", SWIG_From_long((long)(ISO_MAX_PREPARER_ID)));
  rb_define_const(mRubyiso9660, "MAX_ISOPATHNAME", SWIG_From_long((long)(MAX_ISOPATHNAME)));
  rb_define_const(mRubyiso9660, "FILE", SWIG_From_long((long)(ISO_FILE)));
  rb_define_const(mRubyiso9660, "EXISTENCE", SWIG_From_long((long)(ISO_EXISTENCE)));
  rb_define_const(mRubyiso9660, "DIRECTORY", SWIG_From_long((long)(ISO_DIRECTORY)));
  rb_define_const(mRubyiso9660, "ASSOCIATED", SWIG_From_long((long)(ISO_ASSOCIATED)));
  rb_define_const(mRubyiso9660, "RECORD", SWIG_From_long((long)(ISO_RECORD)));
  rb_define_const(mRubyiso9660, "PROTECTION", SWIG_From_long((long)(ISO_PROTECTION)));
  rb_define_const(mRubyiso9660, "DRESERVED1", SWIG_From_long((long)(ISO_DRESERVED1)));
  rb_define_const(mRubyiso9660, "DRESERVED2", SWIG_From_long((long)(ISO_DRESERVED2)));
  rb_define_const(mRubyiso9660, "MULTIEXTENT", SWIG_From_long((long)(ISO_MULTIEXTENT)));
  rb_define_const(mRubyiso9660, "VD_BOOT_RECORD", SWIG_From_long((long)(ISO_VD_BOOT_RECORD)));
  rb_define_const(mRubyiso9660, "VD_PRIMARY", SWIG_From_long((long)(ISO_VD_PRIMARY)));
  rb_define_const(mRubyiso9660, "VD_SUPPLEMENTARY", SWIG_From_long((long)(ISO_VD_SUPPLEMENTARY)));
  rb_define_const(mRubyiso9660, "VD_PARITION", SWIG_From_long((long)(ISO_VD_PARITION)));
  rb_define_const(mRubyiso9660, "VD_END", SWIG_From_long((long)(ISO_VD_END)));
  rb_define_const(mRubyiso9660, "MAX_PUBLISHER_ID", SWIG_From_long((long)(ISO_MAX_PUBLISHER_ID)));
  rb_define_const(mRubyiso9660, "MAX_APPLICATION_ID", SWIG_From_long((long)(ISO_MAX_APPLICATION_ID)));
  rb_define_const(mRubyiso9660, "MAX_VOLUME_ID", SWIG_From_long((long)(ISO_MAX_VOLUME_ID)));
  rb_define_const(mRubyiso9660, "MAX_VOLUMESET_ID", SWIG_From_long((long)(ISO_MAX_VOLUMESET_ID)));
  rb_define_const(mRubyiso9660, "NOCHECK", SWIG_From_long((long)(ISO9660_NOCHECK)));
  rb_define_const(mRubyiso9660, "SEVEN_BIT", SWIG_From_long((long)(ISO9660_7BIT)));
  rb_define_const(mRubyiso9660, "ACHARS", SWIG_From_long((long)(ISO9660_ACHARS)));
  rb_define_const(mRubyiso9660, "DCHARS", SWIG_From_long((long)(ISO9660_DCHARS)));
  rb_define_const(mRubyiso9660, "EXTENSION_JOLIET_LEVEL1", SWIG_From_long((long)(ISO_EXTENSION_JOLIET_LEVEL1)));
  rb_define_const(mRubyiso9660, "EXTENSION_JOLIET_LEVEL2", SWIG_From_long((long)(ISO_EXTENSION_JOLIET_LEVEL2)));
  rb_define_const(mRubyiso9660, "EXTENSION_JOLIET_LEVEL3", SWIG_From_long((long)(ISO_EXTENSION_JOLIET_LEVEL3)));
  rb_define_const(mRubyiso9660, "EXTENSION_ROCK_RIDGE", SWIG_From_long((long)(ISO_EXTENSION_ROCK_RIDGE)));
  rb_define_const(mRubyiso9660, "EXTENSION_HIGH_SIERRA", SWIG_From_long((long)(ISO_EXTENSION_HIGH_SIERRA)));
  rb_define_const(mRubyiso9660, "EXTENSION_ALL", SWIG_From_long((long)(ISO_EXTENSION_ALL)));
  rb_define_const(mRubyiso9660, "EXTENSION_NONE", SWIG_From_long((long)(ISO_EXTENSION_NONE)));
  rb_define_const(mRubyiso9660, "EXTENSION_JOLIET", SWIG_From_long((long)(ISO_EXTENSION_JOLIET)));
  rb_define_module_function(mRubyiso9660, "open_iso", _wrap_open_iso, -1);
  rb_define_module_function(mRubyiso9660, "open_ext", _wrap_open_ext, -1);
  rb_define_module_function(mRubyiso9660, "open_fuzzy", _wrap_open_fuzzy, -1);
  rb_define_module_function(mRubyiso9660, "iso9660_open_fuzzy_ext", _wrap_iso9660_open_fuzzy_ext, -1);
  rb_define_module_function(mRubyiso9660, "ifs_fuzzy_read_superblock", _wrap_ifs_fuzzy_read_superblock, -1);
  rb_define_module_function(mRubyiso9660, "close", _wrap_close, -1);
  
  cBuf_tuple_t.klass = rb_define_class_under(mRubyiso9660, "Buf_tuple_t", rb_cObject);
  SWIG_TypeClientData(SWIGTYPE_p_Buf_tuple_t, (void *) &cBuf_tuple_t);
  rb_define_alloc_func(cBuf_tuple_t.klass, _wrap_Buf_tuple_t_allocate);
  rb_define_method(cBuf_tuple_t.klass, "initialize", _wrap_new_Buf_tuple_t, -1);
  rb_define_method(cBuf_tuple_t.klass, "data=", _wrap_Buf_tuple_t_data_set, -1);
  rb_define_method(cBuf_tuple_t.klass, "data", _wrap_Buf_tuple_t_data_get, -1);
  rb_define_method(cBuf_tuple_t.klass, "i_size=", _wrap_Buf_tuple_t_i_size_set, -1);
  rb_define_method(cBuf_tuple_t.klass, "i_size", _wrap_Buf_tuple_t_i_size_get, -1);
  cBuf_tuple_t.mark = 0;
  cBuf_tuple_t.destroy = (void (*)(void *)) free_Buf_tuple_t;
  cBuf_tuple_t.trackObjects = 0;
  rb_define_module_function(mRubyiso9660, "seek_read", _wrap_seek_read, -1);
  rb_define_module_function(mRubyiso9660, "fs_read_pvd", _wrap_fs_read_pvd, -1);
  rb_define_module_function(mRubyiso9660, "ifs_read_pvd", _wrap_ifs_read_pvd, -1);
  rb_define_module_function(mRubyiso9660, "fs_read_superblock", _wrap_fs_read_superblock, -1);
  rb_define_module_function(mRubyiso9660, "ifs_read_superblock", _wrap_ifs_read_superblock, -1);
  rb_define_module_function(mRubyiso9660, "set_dtime", _wrap_set_dtime, -1);
  rb_define_module_function(mRubyiso9660, "set_ltime", _wrap_set_ltime, -1);
  rb_define_module_function(mRubyiso9660, "get_dtime", _wrap_get_dtime, -1);
  rb_define_module_function(mRubyiso9660, "get_ltime", _wrap_get_ltime, -1);
  rb_define_module_function(mRubyiso9660, "dchar?", _wrap_dcharq___, -1);
  rb_define_module_function(mRubyiso9660, "achar?", _wrap_acharq___, -1);
  rb_define_module_function(mRubyiso9660, "name_translate", _wrap_name_translate, -1);
  rb_define_module_function(mRubyiso9660, "name_translate_ext", _wrap_name_translate_ext, -1);
  rb_define_module_function(mRubyiso9660, "strncpy_pad", _wrap_strncpy_pad, -1);
  rb_define_module_function(mRubyiso9660, "dirname_valid?", _wrap_dirname_validq___, -1);
  rb_define_module_function(mRubyiso9660, "pathname_isofy", _wrap_pathname_isofy, -1);
  rb_define_module_function(mRubyiso9660, "pathname_valid?", _wrap_pathname_validq___, -1);
  rb_define_module_function(mRubyiso9660, "fs_stat", _wrap_fs_stat, -1);
  rb_define_module_function(mRubyiso9660, "fs_stat_translate", _wrap_fs_stat_translate, -1);
  rb_define_module_function(mRubyiso9660, "ifs_stat", _wrap_ifs_stat, -1);
  rb_define_module_function(mRubyiso9660, "ifs_stat_translate", _wrap_ifs_stat_translate, -1);
  rb_define_module_function(mRubyiso9660, "fs_readdir", _wrap_fs_readdir, -1);
  rb_define_module_function(mRubyiso9660, "ifs_readdir", _wrap_ifs_readdir, -1);
  rb_define_module_function(mRubyiso9660, "get_application_id", _wrap_get_application_id, -1);
  rb_define_module_function(mRubyiso9660, "ifs_get_application_id", _wrap_ifs_get_application_id, -1);
  rb_define_module_function(mRubyiso9660, "get_joliet_level", _wrap_get_joliet_level, -1);
  rb_define_module_function(mRubyiso9660, "get_dir_len", _wrap_get_dir_len, -1);
  rb_define_module_function(mRubyiso9660, "iso9660_dir_to_name", _wrap_iso9660_dir_to_name, -1);
  rb_define_module_function(mRubyiso9660, "get_preparer_id", _wrap_get_preparer_id, -1);
  rb_define_module_function(mRubyiso9660, "ifs_get_preparer_id", _wrap_ifs_get_preparer_id, -1);
  rb_define_module_function(mRubyiso9660, "get_publisher_id", _wrap_get_publisher_id, -1);
  rb_define_module_function(mRubyiso9660, "ifs_get_publisher_id", _wrap_ifs_get_publisher_id, -1);
  rb_define_module_function(mRubyiso9660, "get_pvd_type", _wrap_get_pvd_type, -1);
  rb_define_module_function(mRubyiso9660, "get_pvd_id", _wrap_get_pvd_id, -1);
  rb_define_module_function(mRubyiso9660, "get_pvd_space_size", _wrap_get_pvd_space_size, -1);
  rb_define_module_function(mRubyiso9660, "get_pvd_block_size", _wrap_get_pvd_block_size, -1);
  rb_define_module_function(mRubyiso9660, "get_pvd_version", _wrap_get_pvd_version, -1);
  rb_define_module_function(mRubyiso9660, "get_system_id", _wrap_get_system_id, -1);
  rb_define_module_function(mRubyiso9660, "ifs_get_system_id", _wrap_ifs_get_system_id, -1);
  rb_define_module_function(mRubyiso9660, "get_root_lsn", _wrap_get_root_lsn, -1);
  rb_define_module_function(mRubyiso9660, "get_volume_id", _wrap_get_volume_id, -1);
  rb_define_module_function(mRubyiso9660, "ifs_get_volume_id", _wrap_ifs_get_volume_id, -1);
  rb_define_module_function(mRubyiso9660, "get_volumeset_id", _wrap_get_volumeset_id, -1);
  rb_define_module_function(mRubyiso9660, "ifs_get_volumeset_id", _wrap_ifs_get_volumeset_id, -1);
  rb_define_module_function(mRubyiso9660, "pathtable_init", _wrap_pathtable_init, -1);
  rb_define_module_function(mRubyiso9660, "pathtable_get_size", _wrap_pathtable_get_size, -1);
  rb_define_module_function(mRubyiso9660, "pathtable_l_add_entry", _wrap_pathtable_l_add_entry, -1);
  rb_define_module_function(mRubyiso9660, "pathtable_m_add_entry", _wrap_pathtable_m_add_entry, -1);
  rb_define_module_function(mRubyiso9660, "set_evd", _wrap_set_evd, -1);
  rb_define_module_function(mRubyiso9660, "xa?", _wrap_xaq___, -1);
}

